@@ -6,10 +6,12 @@ set -exv
 
 : "${BUILD_STAGINGDIRECTORY:?BUILD_STAGINGDIRECTORY environment variable not set.}"
 
-# IMAGE should be one of 'centos7', 'ubi8' or 'fedora'
+# DOCKERFILE should be one of 'ubi' or 'fedora'
+: "${DOCKERFILE:?DOCKERFILE environment variable not set.}"
+# IMAGE should be RHEL or Fedora image url
 : "${IMAGE:?IMAGE environment variable not set.}"
-# TAG should be 'centos7', '8.4' or Fedora version number
-: "${TAG:?TAG environment variable not set.}"
+# PYTHON_PACKAGE should be python package name
+: "${PYTHON_PACKAGE:?PYTHON_PACKAGE environment variable not set.}"
 
 CLI_VERSION=`cat src/azure-cli/azure/cli/__main__.py | grep __version__ | sed s/' '//g | sed s/'__version__='// |  sed s/\"//g`
 
@@ -17,22 +19,24 @@ CLI_VERSION=`cat src/azure-cli/azure/cli/__main__.py | grep __version__ | sed s/
 docker build \
     --target build-env \
     --build-arg cli_version=${CLI_VERSION} \
-    --build-arg tag=${TAG} \
-    -f ./scripts/release/rpm/${IMAGE}.dockerfile \
-    -t azure/azure-cli:${IMAGE}-builder \
+    --build-arg image=${IMAGE} \
+    --build-arg python_package=${PYTHON_PACKAGE} \
+    -f ./scripts/release/rpm/${DOCKERFILE}.dockerfile \
+    -t azure/azure-cli:${DOCKERFILE}-builder \
     .
 
 # Continue the previous build, and create a container that has the current azure-cli build but not the source code.
 docker build \
     --build-arg cli_version=${CLI_VERSION} \
-    --build-arg tag=${TAG} \
-    -f ./scripts/release/rpm/${IMAGE}.dockerfile \
-    -t azure/azure-cli:${IMAGE} \
+    --build-arg image=${IMAGE} \
+    --build-arg python_package=${PYTHON_PACKAGE} \
+    -f ./scripts/release/rpm/${DOCKERFILE}.dockerfile \
+    -t azure/azure-cli:${DOCKERFILE} \
     .
 
 # Extract the built RPM so that it can be distributed independently.
 # The RPM file looks like azure-cli-2.32.0-1.el7.x86_64.rpm
-id=$(docker create azure/azure-cli:${IMAGE}-builder)
+id=$(docker create azure/azure-cli:${DOCKERFILE}-builder)
 # https://docs.docker.com/engine/reference/commandline/cp/
 # Append /. so that the x86_64 folder's content is copied, instead of x86_64 folder itself.
 docker cp $id:/root/rpmbuild/RPMS/x86_64/. ${BUILD_STAGINGDIRECTORY}
