@@ -4,7 +4,7 @@
 # --------------------------------------------------------------------------------------------
 # pylint: disable=line-too-long
 
-__version__ = "2.39.0"
+__version__ = "2.40.0"
 
 import os
 import sys
@@ -117,19 +117,11 @@ class AzCli(CLI):
 
     def show_version(self):
         from azure.cli.core.util import get_az_version_string, show_updates
-        from azure.cli.core.commands.constants import SURVEY_PROMPT_STYLED, UX_SURVEY_PROMPT_STYLED
-        from azure.cli.core.style import print_styled_text
 
         ver_string, updates_available_components = get_az_version_string()
         print(ver_string)
         show_updates(updates_available_components)
 
-        show_link = self.config.getboolean('output', 'show_survey_link', True)
-        if show_link:
-            print_styled_text()
-            print_styled_text(SURVEY_PROMPT_STYLED)
-            print_styled_text(UX_SURVEY_PROMPT_STYLED)
-
     def exception_handler(self, ex):  # pylint: disable=no-self-use
         from azure.cli.core.util import handle_exception
         return handle_exception(ex)
