@@ -67,6 +67,7 @@ def ensure_default_log_analytics_workspace_for_monitoring(
         "switzerlandnorth": "CHN",
         "switzerlandwest": "CHW",
         "uaecentral": "AUH",
+        "qatarcentral": "QAC",
     }
     AzureCloudRegionToOmsRegionMap = {
         "australiacentral": "australiacentral",
@@ -112,6 +113,7 @@ def ensure_default_log_analytics_workspace_for_monitoring(
         "eastus2euap": "eastus2euap",
         "centraluseuap": "eastus2euap",
         "brazilsoutheast": "brazilsoutheast",
+        "qatarcentral": "qatarcentral",
     }
 
     # mapping for azure china cloud
@@ -298,7 +300,6 @@ def ensure_container_insights_for_monitoring(
     # extract subscription ID and resource group from workspace_resource_id URL
     try:
         subscription_id = workspace_resource_id.split("/")[2]
-        resource_group = workspace_resource_id.split("/")[4]
     except IndexError:
         raise AzCLIError(
             "Could not locate resource group in workspace-resource-id URL."
@@ -324,7 +325,7 @@ def ensure_container_insights_for_monitoring(
         )
         dataCollectionRuleName = f"MSCI-{cluster_name}-{cluster_region}"
         dcr_resource_id = (
-            f"/subscriptions/{subscription_id}/resourceGroups/{resource_group}/"
+            f"/subscriptions/{cluster_subscription}/resourceGroups/{cluster_resource_group_name}/"
             f"providers/Microsoft.Insights/dataCollectionRules/{dataCollectionRuleName}"
         )
         if create_dcr:
@@ -335,7 +336,7 @@ def ensure_container_insights_for_monitoring(
             for _ in range(3):
                 try:
                     location_list_url = cmd.cli_ctx.cloud.endpoints.resource_manager + \
-                        f"/subscriptions/{subscription_id}/locations?api-version=2019-11-01"
+                        f"/subscriptions/{cluster_subscription}/locations?api-version=2019-11-01"
                     r = send_raw_request(cmd.cli_ctx, "GET", location_list_url)
                     # this is required to fool the static analyzer. The else statement will only run if an exception
                     # is thrown, but flake8 will complain that e is undefined if we don't also define it here.
@@ -356,7 +357,7 @@ def ensure_container_insights_for_monitoring(
             for _ in range(3):
                 try:
                     feature_check_url = cmd.cli_ctx.cloud.endpoints.resource_manager + \
-                        f"/subscriptions/{subscription_id}/providers/Microsoft.Insights?api-version=2020-10-01"
+                        f"/subscriptions/{cluster_subscription}/providers/Microsoft.Insights?api-version=2020-10-01"
                     r = send_raw_request(cmd.cli_ctx, "GET", feature_check_url)
                     error = None
                     break
