@@ -48,48 +48,6 @@ class TestFunctionappMocked(unittest.TestCase):
     def setUp(self):
         self.client = WebSiteManagementClient(mock.MagicMock(), '123455678')
 
-    @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
-    @mock.patch('azure.cli.command_modules.appservice.custom.parse_resource_id')
-    @mock.patch('azure.cli.command_modules.appservice.custom.enable_zip_deploy')
-    @mock.patch('azure.cli.command_modules.appservice.custom.add_remote_build_app_settings')
-    def test_functionapp_zip_deploy_flow(self,
-                                         add_remote_build_app_settings_mock,
-                                         enable_zip_deploy_mock,
-                                         parse_resource_id_mock,
-                                         web_client_factory_mock):
-        cmd_mock = _get_test_cmd()
-        cli_ctx_mock = mock.MagicMock()
-        cmd_mock.cli_ctx = cli_ctx_mock
-
-        # action
-        enable_zip_deploy_functionapp(cmd_mock, 'rg', 'name', 'src', build_remote=True, timeout=None, slot=None)
-
-        # assert
-        parse_resource_id_mock.assert_called_once()
-        enable_zip_deploy_mock.assert_called_once()
-        add_remote_build_app_settings_mock.assert_called_once()
-
-    @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
-    @mock.patch('azure.cli.command_modules.appservice.custom.parse_resource_id')
-    @mock.patch('azure.cli.command_modules.appservice.custom.enable_zip_deploy')
-    @mock.patch('azure.cli.command_modules.appservice.custom.remove_remote_build_app_settings')
-    def test_functionapp_zip_deploy_flow(self,
-                                         remove_remote_build_app_settings_mock,
-                                         enable_zip_deploy_mock,
-                                         parse_resource_id_mock,
-                                         web_client_factory_mock):
-        cmd_mock = _get_test_cmd()
-        cli_ctx_mock = mock.MagicMock()
-        cmd_mock.cli_ctx = cli_ctx_mock
-
-        # action
-        enable_zip_deploy_functionapp(cmd_mock, 'rg', 'name', 'src', build_remote=False, timeout=None, slot=None)
-
-        # assert
-        parse_resource_id_mock.assert_called_once()
-        enable_zip_deploy_mock.assert_called_once()
-        remove_remote_build_app_settings_mock.assert_called_once()
-
     @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
     @mock.patch('azure.cli.command_modules.appservice.custom.parse_resource_id')
     @mock.patch('azure.cli.command_modules.appservice.custom.upload_zip_to_storage')
@@ -120,15 +78,15 @@ class TestFunctionappMocked(unittest.TestCase):
         web_client_mock.web_apps.get.assert_called_with('rg', 'name')
         upload_zip_to_storage_mock.assert_called_with(cmd_mock, 'rg', 'name', 'src', None)
 
-    @mock.patch('azure.cli.command_modules.appservice.custom.add_remote_build_app_settings')
     @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
     @mock.patch('azure.cli.command_modules.appservice.custom.parse_resource_id')
-    @mock.patch('azure.cli.command_modules.appservice.custom.enable_zip_deploy')
-    def test_functionapp_remote_build_supports_linux(self,
-                                                     enable_zip_deploy_mock,
-                                                     parse_resource_id_mock,
-                                                     web_client_factory_mock,
-                                                     add_remote_build_app_settings_mock):
+    @mock.patch('azure.cli.command_modules.appservice.custom.upload_zip_to_storage')
+    @mock.patch('azure.cli.command_modules.appservice.custom.is_plan_consumption', return_value=True)
+    def test_functionapp_linux_consumption_non_remote_build_with_slot(self,
+                                                            is_plan_consumption_mock,
+                                                            upload_zip_to_storage_mock,
+                                                            parse_resource_id_mock,
+                                                            web_client_factory_mock):
         # prepare
         cmd_mock = _get_test_cmd()
         cli_ctx_mock = mock.MagicMock()
@@ -143,11 +101,57 @@ class TestFunctionappMocked(unittest.TestCase):
         web_client_factory_mock.return_value = web_client_mock
 
         # action
-        enable_zip_deploy_functionapp(cmd_mock, 'rg', 'name', 'src', build_remote=True, timeout=None, slot=None)
+        # Linux Consumption app should use update-storage to deploy when not using remote build
+        enable_zip_deploy_functionapp(cmd_mock, 'rg', 'name', 'src', build_remote=False, timeout=None, slot='slot')
 
         # assert
         web_client_mock.web_apps.get.assert_called_with('rg', 'name')
-        enable_zip_deploy_mock.assert_called_with(cmd_mock, 'rg', 'name', 'src', None, None)
+        upload_zip_to_storage_mock.assert_called_with(cmd_mock, 'rg', 'name', 'src', 'slot')
+
+    @mock.patch('azure.cli.command_modules.appservice.custom._get_scm_url', return_value='https://mock-scm')
+    @mock.patch('azure.cli.command_modules.appservice.custom._get_site_credential', return_value=('usr', 'pwd'))
+    @mock.patch('azure.cli.command_modules.appservice.custom.get_webapp')
+    @mock.patch('azure.cli.command_modules.appservice.custom._check_scm_zip_deployment_status')
+    @mock.patch('azure.cli.command_modules.appservice.custom.add_remote_build_app_settings')
+    @mock.patch('azure.cli.command_modules.appservice.custom.web_client_factory', autospec=True)
+    @mock.patch('azure.cli.command_modules.appservice.custom.parse_resource_id')
+    @mock.patch('requests.post', autospec=True)
+    def test_functionapp_remote_build_supports_linux(self,
+                                                     requests_post_mock,
+                                                     parse_resource_id_mock,
+                                                     web_client_factory_mock,
+                                                     add_remote_build_app_settings_mock,
+                                                     status_mock,
+                                                     get_webapp_mock,
+                                                     get_site_credential_mock,
+                                                     get_scm_url_mock):
+        # prepare
+        cmd_mock = _get_test_cmd()
+        cli_ctx_mock = mock.MagicMock()
+        cmd_mock.cli_ctx = cli_ctx_mock
+
+        response = mock.MagicMock()
+        response.status_code = 202
+        requests_post_mock.return_value = response
+
+        appservice_mock = mock.Mock()
+        appservice_mock.reserved = True  # Marked app service as Linux
+        get_webapp_mock.return_value.reserved = True
+
+        web_client_mock = mock.Mock()
+        web_client_mock.web_apps = mock.Mock()
+        web_client_mock.web_apps.get = mock.Mock(return_value=appservice_mock)
+        web_client_factory_mock.return_value = web_client_mock
+
+        expected_zip_deploy_headers = _get_zip_deploy_headers('usr', 'pwd', cmd_mock.cli_ctx)
+
+        # action
+        with mock.patch('builtins.open', new_callable=mock.mock_open, read_data='zip-content'):
+            enable_zip_deploy_functionapp(cmd_mock, 'rg', 'name', 'src', build_remote=True, timeout=None, slot=None)
+
+        # assert
+        requests_post_mock.assert_called_with('https://mock-scm/api/zipdeploy?isAsync=true', data='zip-content',
+                                              headers=expected_zip_deploy_headers, verify=mock.ANY)
 
     @mock.patch('azure.cli.command_modules.appservice.custom._get_site_credential', return_value=('usr', 'pwd'))
     @mock.patch('azure.cli.command_modules.appservice.custom._get_scm_url', side_effect=ValueError())
@@ -167,16 +171,18 @@ class TestFunctionappMocked(unittest.TestCase):
         # assert
         get_site_credential_mock.assert_called_with(cmd_mock.cli_ctx, 'rg', 'name', None)
         get_scm_url_mock.assert_called_with(cmd_mock, 'rg', 'name', None)
-    
+
+    @mock.patch('azure.cli.command_modules.appservice.custom.get_webapp')
     @mock.patch('azure.cli.command_modules.appservice.custom._get_site_credential', return_value=('usr', 'pwd'))
     @mock.patch('azure.cli.command_modules.appservice.custom._get_scm_url', return_value='https://mock-scm')
     @mock.patch('requests.post', autospec=True)
-    @mock.patch('azure.cli.command_modules.appservice.custom._check_zip_deployment_status')
+    @mock.patch('azure.cli.command_modules.appservice.custom._check_scm_zip_deployment_status')
     def test_enable_zip_deploy_accepted(self,
                                         check_zip_deployment_status_mock,
                                         requests_post_mock,
                                         get_scm_url_mock,
-                                        get_site_credential_mock):
+                                        get_site_credential_mock,
+                                        get_webapp_mock):
         # prepare
         cmd_mock = _get_test_cmd()
         cli_ctx_mock = mock.MagicMock()
@@ -186,6 +192,8 @@ class TestFunctionappMocked(unittest.TestCase):
         response.status_code = 202
         requests_post_mock.return_value = response
 
+        get_webapp_mock.return_value.reserved = False
+
         expected_zip_deploy_headers = _get_zip_deploy_headers('usr', 'pwd', cmd_mock.cli_ctx)
 
         # action
@@ -199,13 +207,15 @@ class TestFunctionappMocked(unittest.TestCase):
         check_zip_deployment_status_mock.assert_called_with(cmd_mock, 'rg', 'name',
                                                             'https://mock-scm/api/deployments/latest', mock.ANY, None)
 
+    @mock.patch('azure.cli.command_modules.appservice.custom.get_webapp')
     @mock.patch('azure.cli.command_modules.appservice.custom._get_site_credential', return_value=('usr', 'pwd'))
     @mock.patch('azure.cli.command_modules.appservice.custom._get_scm_url', return_value='https://mock-scm')
     @mock.patch('requests.post', autospec=True)
     def test_enable_zip_deploy_conflict(self,
                                         requests_post_mock,
                                         get_scm_url_mock,
-                                        get_site_credential_mock):
+                                        get_site_credential_mock,
+                                        *args):
         # prepare
         cmd_mock = _get_test_cmd()
         cli_ctx_mock = mock.MagicMock()
@@ -223,16 +233,18 @@ class TestFunctionappMocked(unittest.TestCase):
                 enable_zip_deploy(cmd_mock, 'rg', 'name', 'src', slot=None)
 
         # assert
-        requests_post_mock.assert_called_with('https://mock-scm/api/zipdeploy?isAsync=true', data='zip-content',
+        requests_post_mock.assert_called_with('https://mock-scm/api/zipdeploy?isAsync=true&trackDeploymentProgress=true', data='zip-content',
                                               headers=expected_zip_deploy_headers, verify=mock.ANY)
 
+    @mock.patch('azure.cli.command_modules.appservice.custom.get_webapp')
     @mock.patch('azure.cli.command_modules.appservice.custom._get_site_credential', return_value=('usr', 'pwd'))
     @mock.patch('azure.cli.command_modules.appservice.custom._get_scm_url', return_value='https://mock-scm')
     @mock.patch('requests.post', autospec=True)
     def test_enable_zip_deploy_service_unavailable(self,
                                                    requests_post_mock,
                                                    get_scm_url_mock,
-                                                   get_site_credential_mock):
+                                                   get_site_credential_mock,
+                                                   *args):
         # prepare
         cmd_mock = _get_test_cmd()
         cli_ctx_mock = mock.MagicMock()
@@ -250,7 +262,7 @@ class TestFunctionappMocked(unittest.TestCase):
                 enable_zip_deploy(cmd_mock, 'rg', 'name', 'src', slot=None)
 
         # assert
-        requests_post_mock.assert_called_with('https://mock-scm/api/zipdeploy?isAsync=true', data='zip-content',
+        requests_post_mock.assert_called_with('https://mock-scm/api/zipdeploy?isAsync=true&trackDeploymentProgress=true', data='zip-content',
                                               headers=expected_zip_deploy_headers, verify=mock.ANY)
 
     @mock.patch('azure.cli.command_modules.appservice.custom._get_app_settings_from_scm', return_value={
