@@ -11,23 +11,23 @@ import json
 import os
 
 
-id_hana = '/subscriptions/38304e13-357e-405e-9e9a-220351dcce8c/resourceGroups/SAPHANA-CLITEST-RG/providers/Microsoft.Compute/virtualMachines/saphana-clitest-vm2'
-item_id_hana = '/subscriptions/38304e13-357e-405e-9e9a-220351dcce8c/resourceGroups/saphana-clitest-rg/providers/Microsoft.RecoveryServices/vaults/saphana-clitest-vault2/backupFabrics/Azure/protectionContainers/VMAppContainer;compute;saphana-clitest-rg;saphana-clitest-vm2/protectedItems/SAPHanaDatabase;hxe;hdb'
+id_hana = '/subscriptions/38304e13-357e-405e-9e9a-220351dcce8c/resourceGroups/saphana-clitest-rg/providers/Microsoft.Compute/virtualMachines/saphana-clitestvm-donotuse'
+item_id_hana = '/subscriptions/38304e13-357e-405e-9e9a-220351dcce8c/resourcegroups/saphana-clitest-rg/providers/Microsoft.RecoveryServices/vaults/saphana-clitestvm-donotuse/backupFabrics/Azure/protectionContainers/VMAppContainer;compute;saphana-clitest-rg;saphana-clitestvm-donotuse/protectedItems/SAPHanaDatabase;hxe;hxe'
 sub_hana = '38304e13-357e-405e-9e9a-220351dcce8c'
 rg_hana = 'saphana-clitest-rg'
-vault_hana = 'saphana-clitest-vault2'
-container_hana = 'VMAppContainer;Compute;saphana-clitest-rg;saphana-clitest-vm2'
-container_friendly_hana = 'saphana-clitest-vm2'
-item1_hana = 'SAPHanaDatabase;hxe;hdb'
-item2_hana = 'SYSTEMDB'
-
+vault_hana = 'saphana-clitestvault-donotuse'
+container_hana = 'VMAppContainer;Compute;saphana-clitest-rg;saphana-clitestvm-donotuse'
+container_friendly_hana = 'saphana-clitestvm-donotuse'
+server_friendly_name = 'saphana-clitestvm-donotuse'
+item_name = 'saphanadatabase;hxe;systemdb'
+item_friendly_name = 'systemdb'
 
 class BackupTests(ScenarioTest, unittest.TestCase):
 
     # SAP HANA workload tests start here
     # Please make sure you have the following setup in place before running the tests -
 
-    # For the tests using saphana-clitest-vm2 and saphana-clitest-vault2 -
+    # For the tests using saphana-clitestvm-donotuse and saphana-clitestvault-donotuse -
     # Each test will register the container at the start and unregister at the end of the test
     # Make sure that the container is not already registered since the start of the test
 
@@ -153,10 +153,10 @@ class BackupTests(ScenarioTest, unittest.TestCase):
 
         self.kwargs.update({
             'vault': vault_hana,
-            'policy': 'saphana-clitest-policy',
+            'policy': 'saphana-clitestpolicy-donotuse',
             'wt': 'SAPHANA',
             'sub': sub_hana,
-            'default': 'saphana-clitest-policy',
+            'default': 'saphana-clitestpolicy-donotuse',
             'rg': rg_hana,
             'pit': 'HANADataBase',
             'policy_new': self.create_random_name('clitest-policy', 24)
@@ -199,16 +199,15 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         self.kwargs.update({
             'vault': vault_hana,
             'name': container_hana,
-            'fname': 'saphana-clitest-vm2',
-            'policy': 'saphana-clitest-policy',
+            'fname': server_friendly_name,
+            'policy': 'saphana-clitestpolicy-donotuse',
             'wt': 'SAPHANA',
             'sub': sub_hana,
-            'default': 'saphana-clitest-policy',
+            'default': 'saphana-clitestpolicy-donotuse',
             'rg': rg_hana,
-            'item': "saphanadatabase;hxe;systemdb",
-            'fitem': "systemdb",
+            'item': item_name,
+            'fitem': item_friendly_name,
             'id': id_hana,
-            'item_id': item_id_hana,
             'pit': 'SAPHanaDatabase'
         })
         self.cmd('backup container register -v {vault} -g {rg} --backup-management-type AzureWorkload --workload-type {wt} --resource-id {id}')
@@ -276,7 +275,7 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         ])
 
         item1_json = self.cmd('backup item show -g {rg} -v {vault} -c {container1} -n {item} --backup-management-type AzureWorkload --workload-type SAPHanaDatabase').get_output_in_json()
-        self.assertIn("saphana-clitest-policy".lower(), item1_json['properties']['policyId'].lower())
+        self.assertIn("saphana-clitestpolicy-donotuse".lower(), item1_json['properties']['policyId'].lower())
 
         self.cmd('backup protection disable -v {vault} -g {rg} -c {container1} --backup-management-type AzureWorkload --workload-type {wt} -i {item} -y --delete-backup-data true')
 
@@ -291,15 +290,13 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         self.kwargs.update({
             'vault': vault_hana,
             'name': container_hana,
-            'fname': 'saphana-clitest-vm2',
-            'policy': 'saphana-clitest-policy',
+            'fname': server_friendly_name,
+            'policy': 'saphana-clitestpolicy-donotuse',
             'wt': 'SAPHANA',
             'sub': sub_hana,
-            'default': 'saphana-clitest-policy',
+            'default': 'saphana-clitestpolicy-donotuse',
             'rg': rg_hana,
-            'item': item1_hana,
             'id': id_hana,
-            'item_id': item_id_hana,
             'pit': 'SAPHanaDatabase',
             'protectable_item_name': 'SYSTEMDB',
             'pit_hana': 'SAPHanaDatabase'
@@ -336,15 +333,14 @@ class BackupTests(ScenarioTest, unittest.TestCase):
             'vault': vault_hana,
             'name': container_hana,
             'rg': resource_group,
-            'fname': 'saphana-clitest-vm2',
-            'policy': 'saphana-clitest-policy',
+            'fname': server_friendly_name,
+            'policy': 'saphana-clitestpolicy-donotuse',
             'wt': 'SAPHANA',
             'sub': sub_hana,
-            'item': 'saphanadatabase;hxe;systemdb',
+            'item': item_name,
             'pit': "SAPHanaDatabase",
-            'item_id': item_id_hana,
             'id': id_hana,
-            'fitem': "systemdb",
+            'fitem': item_friendly_name,
         })
         self.cmd('backup container register -v {vault} -g {rg} --backup-management-type AzureWorkload --workload-type {wt} --resource-id {id}')
 
@@ -385,18 +381,17 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         self.kwargs.update({
             'vault': vault_hana,
             'name': container_hana,
-            'fname': 'saphana-clitest-vm2',
-            'policy': 'saphana-clitest-policy',
+            'fname': server_friendly_name,
+            'policy': 'saphana-clitestpolicy-donotuse',
             'wt': 'SAPHANA',
             'sub': sub_hana,
-            'default': 'saphana-clitest-policy',
+            'default': 'saphana-clitestpolicy-donotuse',
             'rg': rg_hana,
-            'item': "saphanadatabase;hxe;systemdb",
-            'fitem': "systemdb",
+            'item': item_name,
+            'fitem': item_friendly_name,
             'id': id_hana,
-            'item_id': item_id_hana,
             'pit': "SAPHanaDatabase",
-            'entityFriendlyName': 'SYSTEMDB [saphana-clitest-vm2]'
+            'entityFriendlyName': 'SYSTEMDB [saphana-clitestvm-donotuse]'
         })
         self.cmd('backup container register -v {vault} -g {rg} --backup-management-type AzureWorkload --workload-type {wt} --resource-id {id}')
 
@@ -459,18 +454,16 @@ class BackupTests(ScenarioTest, unittest.TestCase):
         self.kwargs.update({
             'vault': vault_hana,
             'name': container_hana,
-            'fname': 'saphana-clitest-vm2',
-            'policy': 'saphana-clitest-policy',
+            'fname': server_friendly_name,
+            'policy': 'saphana-clitestpolicy-donotuse',
             'wt': 'SAPHANA',
             'sub': sub_hana,
-            'default': 'saphana-clitest-policy',
+            'default': 'saphana-clitestpolicy-donotuse',
             'rg': resource_group,
-            'item': "saphanadatabase;hxe;systemdb",
-            'fitem': "systemdb",
+            'item': item_name,
+            'fitem': item_friendly_name,
             'id': id_hana,
-            'item_id': item_id_hana,
             'pit': 'SAPHanaDatabase',
-            'entityFriendlyName': 'SYSTEMDB [saphana-clitest-vm2]',
             'tpit': 'HANAInstance',
             'titem': 'HDB'
         })
