@@ -26,7 +26,8 @@ from azure.cli.command_modules.cosmosdb._client_factory import (
     cf_restorable_mongodb_resources,
     cf_db_locations,
     cf_cassandra_cluster,
-    cf_cassandra_data_center
+    cf_cassandra_data_center,
+    cf_service
 )
 
 from azure.cli.command_modules.cosmosdb._format import (
@@ -127,6 +128,10 @@ def load_command_table(self, _):
         operations_tmpl='azure.mgmt.cosmosdb.operations#CassandraDataCentersOperations.{}',
         client_factory=cf_cassandra_data_center)
 
+    cosmosdb_service_sdk = CliCommandType(
+        operations_tmpl='azure.mgmt.cosmosdb.operations#ServiceOperations.{}',
+        client_factory=cf_service)
+
     with self.command_group('cosmosdb', cosmosdb_sdk, client_factory=cf_db_accounts) as g:
         g.show_command('show', 'get', transform=transform_db_account_json_output)
         g.command('list-keys', 'list_keys', deprecate_info=g.deprecate(redirect='cosmosdb keys list', hide=True))
@@ -411,3 +416,11 @@ def load_command_table(self, _):
         g.command('list', 'list')
         g.show_command('show', 'get')
         g.command('delete', 'begin_delete', confirmation=True, supports_no_wait=True)
+
+    # ComputeV2 services
+    with self.command_group('cosmosdb service', cosmosdb_service_sdk, client_factory=cf_service) as g:
+        g.custom_command('create', 'cli_cosmosdb_service_create', supports_no_wait=True)
+        g.custom_command('update', 'cli_cosmosdb_service_update', supports_no_wait=True)
+        g.command('list', 'list')
+        g.show_command('show', 'get')
+        g.command('delete', 'begin_delete', confirmation=True, supports_no_wait=True)
