@@ -16,7 +16,7 @@ from azure.cli.core.profiles import ResourceType
 def cli_namespace_create(cmd, client, resource_group_name, namespace_name, location=None, tags=None, sku='Standard', capacity=None,
                          is_auto_inflate_enabled=None, maximum_throughput_units=None, is_kafka_enabled=None,
                          default_action=None, identity=None, zone_redundant=None, cluster_arm_id=None, trusted_service_access_enabled=None,
-                         disable_local_auth=None, mi_system_assigned=None, mi_user_assigned=None, encryption_config=None):
+                         disable_local_auth=None, mi_system_assigned=None, mi_user_assigned=None, encryption_config=None, minimum_tls_version=None):
     EHNamespace = cmd.get_models('EHNamespace', resource_type=ResourceType.MGMT_EVENTHUB)
     Sku = cmd.get_models('Sku', resource_type=ResourceType.MGMT_EVENTHUB)
     Identity = cmd.get_models('Identity', resource_type=ResourceType.MGMT_EVENTHUB)
@@ -35,6 +35,7 @@ def cli_namespace_create(cmd, client, resource_group_name, namespace_name, locat
         ehparam.zone_redundant = zone_redundant
         ehparam.disable_local_auth = disable_local_auth
         ehparam.cluster_arm_id = cluster_arm_id
+        ehparam.minimum_tls_version = minimum_tls_version
 
         if identity or mi_system_assigned:
             ehparam.identity = Identity(type=IdentityType.SYSTEM_ASSIGNED)
@@ -72,7 +73,7 @@ def cli_namespace_create(cmd, client, resource_group_name, namespace_name, locat
 def cli_namespace_update(cmd, client, instance, tags=None, sku=None, capacity=None, is_auto_inflate_enabled=None,
                          maximum_throughput_units=None, is_kafka_enabled=None, default_action=None,
                          identity=None, key_source=None, key_name=None, key_vault_uri=None, key_version=None, trusted_service_access_enabled=None,
-                         disable_local_auth=None, require_infrastructure_encryption=None):
+                         disable_local_auth=None, require_infrastructure_encryption=None, minimum_tls_version=None):
     Encryption = cmd.get_models('Encryption', resource_type=ResourceType.MGMT_EVENTHUB)
     KeyVaultProperties = cmd.get_models('KeyVaultProperties', resource_type=ResourceType.MGMT_EVENTHUB)
     Identity = cmd.get_models('Identity', resource_type=ResourceType.MGMT_EVENTHUB)
@@ -92,15 +93,18 @@ def cli_namespace_update(cmd, client, instance, tags=None, sku=None, capacity=No
         if is_auto_inflate_enabled is not None:
             instance.is_auto_inflate_enabled = is_auto_inflate_enabled
 
-        if maximum_throughput_units:
+        if maximum_throughput_units is not None:
             instance.maximum_throughput_units = maximum_throughput_units
 
-        if is_kafka_enabled:
+        if is_kafka_enabled is not None:
             instance.kafka_enabled = is_kafka_enabled
 
+        if minimum_tls_version:
+            instance.minimum_tls_version = minimum_tls_version
+
         if identity is True and instance.identity is None:
             instance.identity = Identity(type=IdentityType.SYSTEM_ASSIGNED)
-        elif instance.identity and instance.encryption is None:
+        elif instance.identity and (key_name or key_vault_uri or key_version or key_source):
             instance.encryption = Encryption()
             if key_source:
                 instance.encryption.key_source = key_source
@@ -118,7 +122,7 @@ def cli_namespace_update(cmd, client, instance, tags=None, sku=None, capacity=No
             netwrokruleset.trusted_service_access_enabled = trusted_service_access_enabled
             client.create_or_update_network_rule_set(resourcegroup, instance.name, netwrokruleset)
 
-        if disable_local_auth:
+        if disable_local_auth is not None:
             instance.disable_local_auth = disable_local_auth
 
     return instance
@@ -138,7 +142,7 @@ def cli_namespace_exists(client, name):
 
 
 # Cluster region
-def cli_cluster_create(cmd, client, resource_group_name, cluster_name, location=None, tags=None, capacity=None):
+def cli_cluster_create(cmd, client, resource_group_name, cluster_name, location=None, tags=None, capacity=None, supports_scaling=None):
     Cluster = cmd.get_models('Cluster', resource_type=ResourceType.MGMT_EVENTHUB)
     ClusterSku = cmd.get_models('ClusterSku', resource_type=ResourceType.MGMT_EVENTHUB)
 
@@ -146,9 +150,17 @@ def cli_cluster_create(cmd, client, resource_group_name, cluster_name, location=
         ehparam = Cluster()
         ehparam.sku = ClusterSku(name='Dedicated')
         ehparam.location = location
-        if not capacity:
+
+        if capacity:
+            ehparam.sku.capacity = capacity
+        else:
             ehparam.sku.capacity = 1
+
+        if supports_scaling is not None:
+            ehparam.supports_scaling = supports_scaling
+
         ehparam.tags = tags
+
         cluster_result = client.begin_create_or_update(
             resource_group_name=resource_group_name,
             cluster_name=cluster_name,
@@ -157,10 +169,15 @@ def cli_cluster_create(cmd, client, resource_group_name, cluster_name, location=
     return cluster_result
 
 
-def cli_cluster_update(cmd, instance, tags=None):
+def cli_cluster_update(cmd, instance, tags=None, capacity=None):
     if cmd.supported_api_version(resource_type=ResourceType.MGMT_EVENTHUB, min_api='2016-06-01-preview'):
+
         if tags:
             instance.tags = tags
+
+        if capacity:
+            instance.sku.capacity = capacity
+
     return instance
 
 
@@ -212,7 +229,7 @@ def cli_eheventhub_create(cmd, client, resource_group_name, namespace_name, even
         if status:
             eventhubparameter1.status = status
 
-        if enabled and enabled is True:
+        if enabled is not None and enabled is True:
             eventhubparameter1.capture_description = CaptureDescription(
                 enabled=enabled,
                 skip_empty_archives=skip_empty_archives,
