@@ -131,7 +131,13 @@ def load_arguments(self, _):
         c.argument('enabled_for_template_deployment', arg_type=get_three_state_flag(),
                    help='[Vault Only] Property to specify whether Azure Resource Manager is permitted to retrieve '
                         'secrets from the key vault.')
-        c.argument('enable_rbac_authorization', arg_type=get_three_state_flag())
+        c.argument('enable_rbac_authorization', arg_type=get_three_state_flag(),
+                   help='Property that controls how data actions are authorized. When true, the key vault will use '
+                        'Role Based Access Control (RBAC) for authorization of data actions, and the access policies '
+                        'specified in vault properties will be ignored. When false, the key vault will use the access '
+                        'policies specified in vault properties, and any policy stored on Azure Resource Manager will '
+                        'be ignored. If null or not specified, the vault is created with the default value of false. '
+                        'Note that management actions are always authorized with RBAC.')
         c.argument('enable_soft_delete', arg_type=get_three_state_flag(), deprecate_info=c.deprecate(
             message_func=lambda x: 'Warning! The ability to create new key vaults with soft delete disabled will be '
                                    'deprecated by December 2020. All key vaults will be required to have soft delete '
@@ -140,7 +146,12 @@ def load_arguments(self, _):
                    help='[Vault Only] Property to specify whether the \'soft delete\' functionality is enabled for '
                         'this key vault. If it\'s not set to any value (true or false) when creating new key vault, it '
                         'will be set to true by default. Once set to true, it cannot be reverted to false.')
-        c.argument('enable_purge_protection', arg_type=get_three_state_flag())
+        c.argument('enable_purge_protection', arg_type=get_three_state_flag(),
+                   help='Property specifying whether protection against purge is enabled for this vault/managed HSM '
+                        'pool. Setting this property to true activates protection against purge for this vault/managed '
+                        'HSM pool and its content - only the Key Vault/Managed HSM service may initiate a hard, '
+                        'irrecoverable deletion. The setting is effective only if soft delete is also enabled. '
+                        'Enabling this functionality is irreversible.')
         c.argument('public_network_access', arg_type=get_enum_type(PublicNetworkAccess),
                    help="Property to specify whether the vault will accept traffic from public internet. If set to "
                         "'disabled' all traffic except private endpoint traffic and that originates from trusted "
