@@ -50,3 +50,7 @@ def vaults_mgmt_client_factory(cli_ctx, _):
 
 def subvolumes_mgmt_client_factory(cli_ctx, _):
     return cf_netappfiles(cli_ctx).subvolumes
+
+
+def volume_groups_mgmt_client_factory(cli_ctx, _):
+    return cf_netappfiles(cli_ctx).volume_groups
