@@ -10,9 +10,12 @@ import time
 
 POOL_DEFAULT = "--service-level 'Premium' --size 4"
 VOLUME_DEFAULT = "--service-level 'Premium' --usage-threshold 100"
-RG_LOCATION = "southcentralusstage"
-DP_RG_LOCATION = "eastus2euap"
-VNET_LOCATION = "southcentralus"
+#RG_LOCATION = "southcentralusstage"
+#DP_RG_LOCATION = "eastus2euap"
+#VNET_LOCATION = "southcentralus"
+RG_LOCATION = "westus2"
+DP_RG_LOCATION = "eastus"
+VNET_LOCATION = "westus2"
 GIB_SCALE = 1024 * 1024 * 1024
 
 # No tidy up of tests required. The resource group is automatically removed
@@ -460,7 +463,7 @@ class AzureNetAppFilesVolumeServiceScenarioTest(ScenarioTest):
         volume_payload = "--service-level 'Standard' --usage-threshold 200"
 
         volume = self.create_volume(account_name, pool_name, volume_name, '{rg}', pool_payload=pool_payload, volume_payload=volume_payload)
-
+        assert volume['name'] == account_name + '/' + pool_name + '/' + volume_name
         # add an export policy
         # there is already one default rule present
         vol_with_export_policy = self.cmd("netappfiles volume export-policy add -g {rg} -a %s -p %s -v %s --allowed-clients '1.2.3.0/24' --rule-index 3 --unix-read-only true --unix-read-write false --cifs false --nfsv3 true --nfsv41 false" % (account_name, pool_name, volume_name)).get_output_in_json()
