@@ -16,20 +16,17 @@ from azure.cli.command_modules.network._client_factory import (
     cf_express_route_circuit_peerings, cf_express_route_circuits,
     cf_express_route_service_providers, cf_load_balancers, cf_local_network_gateways,
     cf_network_interfaces, cf_network_security_groups, cf_network_watcher, cf_packet_capture,
-    cf_route_tables, cf_routes, cf_route_filter_rules, cf_route_filters, cf_virtual_networks,
-    cf_virtual_network_peerings, cf_virtual_network_gateway_connections,
+    cf_virtual_networks, cf_virtual_network_peerings, cf_virtual_network_gateway_connections,
     cf_virtual_network_gateways, cf_traffic_manager_mgmt_endpoints,
     cf_traffic_manager_mgmt_profiles, cf_dns_mgmt_record_sets, cf_dns_mgmt_zones,
-    cf_tm_geographic, cf_security_rules, cf_subnets, cf_usages, cf_service_community,
+    cf_tm_geographic, cf_security_rules, cf_subnets, cf_usages,
     cf_public_ip_addresses, cf_endpoint_services, cf_connection_monitor,
-    cf_ddos_protection_plans, cf_public_ip_prefixes, cf_service_endpoint_policies,
-    cf_service_endpoint_policy_definitions, cf_dns_references, cf_private_endpoints, cf_network_profiles,
+    cf_ddos_protection_plans, cf_public_ip_prefixes, cf_dns_references, cf_private_endpoints, cf_network_profiles,
     cf_express_route_circuit_connections, cf_express_route_gateways, cf_express_route_connections,
     cf_express_route_ports, cf_express_route_port_locations, cf_express_route_links, cf_app_gateway_waf_policy,
     cf_service_tags, cf_private_link_services, cf_private_endpoint_types, cf_peer_express_route_circuit_connections,
     cf_virtual_router, cf_virtual_router_peering, cf_service_aliases, cf_bastion_hosts, cf_flow_logs,
-    cf_private_dns_zone_groups, cf_load_balancer_backend_pools,
-    cf_network_virtual_appliances, cf_virtual_appliance_skus, cf_virtual_appliance_sites, cf_virtual_hub,
+    cf_private_dns_zone_groups, cf_load_balancer_backend_pools, cf_virtual_hub,
     cf_virtual_hub_bgp_connection, cf_virtual_hub_bgp_connections, cf_custom_ip_prefixes)
 from azure.cli.command_modules.network._util import (
     list_network_resource_property, get_network_resource_property_entry, delete_network_resource_property_entry,
@@ -51,7 +48,7 @@ from azure.cli.command_modules.network._validators import (
     process_ag_create_namespace, process_ag_http_listener_create_namespace, process_ag_listener_create_namespace, process_ag_settings_create_namespace, process_ag_http_settings_create_namespace,
     process_ag_rule_create_namespace, process_ag_routing_rule_create_namespace, process_ag_ssl_policy_set_namespace, process_ag_url_path_map_create_namespace,
     process_ag_url_path_map_rule_create_namespace, process_auth_create_namespace, process_nic_create_namespace,
-    process_lb_create_namespace, process_lb_frontend_ip_namespace, process_local_gateway_create_namespace,
+    process_lb_create_namespace, process_lb_frontend_ip_namespace,
     process_nw_cm_create_namespace,
     process_nw_cm_v2_endpoint_namespace, process_nw_cm_v2_test_configuration_namespace,
     process_nw_cm_v2_test_group, process_nw_cm_v2_output_namespace,
@@ -60,7 +57,7 @@ from azure.cli.command_modules.network._validators import (
     process_nw_troubleshooting_start_namespace, process_nw_troubleshooting_show_namespace,
     process_public_ip_create_namespace, process_tm_endpoint_create_namespace,
     process_vnet_create_namespace, process_vnet_gateway_create_namespace, process_vnet_gateway_update_namespace,
-    process_vpn_connection_create_namespace, process_route_table_create_namespace,
+    process_vpn_connection_create_namespace,
     process_lb_outbound_rule_namespace, process_nw_config_diagnostic_namespace, process_list_delegations_namespace,
     process_appgw_waf_policy_update, process_cross_region_lb_frontend_ip_namespace, process_cross_region_lb_create_namespace)
 
@@ -248,23 +245,6 @@ def load_command_table(self, _):
         min_api='2018-07-01'
     )
 
-    network_rf_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#RouteFiltersOperations.{}',
-        client_factory=cf_route_filters,
-        min_api='2016-12-01'
-    )
-
-    network_rfr_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#RouteFilterRulesOperations.{}',
-        client_factory=cf_route_filter_rules,
-        min_api='2016-12-01'
-    )
-
-    network_rt_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#RouteTablesOperations.{}',
-        client_factory=cf_route_tables
-    )
-
     network_service_tags_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.network.operations#ServiceTagsOperations.{}',
         client_factory=cf_service_tags,
@@ -331,18 +311,6 @@ def load_command_table(self, _):
         client_factory=cf_packet_capture
     )
 
-    network_sepd_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#ServiceEndpointPolicyDefinitionsOperations.{}',
-        client_factory=cf_service_endpoint_policy_definitions,
-        min_api='2018-07-01'
-    )
-
-    network_sepp_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#ServiceEndpointPoliciesOperations.{}',
-        client_factory=cf_service_endpoint_policies,
-        min_api='2018-07-01'
-    )
-
     network_virtual_hub_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.network.operations#VirtualHubsOperations.{}',
         client_factory=cf_virtual_hub,
@@ -415,24 +383,6 @@ def load_command_table(self, _):
         min_api='2019-11-01'
     )
 
-    network_virtual_appliances_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#NetworkVirtualAppliancesOperations.{}',
-        client_factory=cf_network_virtual_appliances,
-        min_api='2020-05-01'
-    )
-
-    virtual_appliance_skus_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#VirtualApplianceSkusOperations.{}',
-        client_factory=cf_virtual_appliance_skus,
-        min_api='2020-05-01'
-    )
-
-    virtual_appliance_sites_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#VirtualApplianceSitesOperations.{}',
-        client_factory=cf_virtual_appliance_sites,
-        min_api='2020-05-01'
-    )
-
     network_custom_ip_prefix_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.network.operations#CustomIPPrefixesOperations.{}',
         client_factory=cf_custom_ip_prefixes,
@@ -1053,12 +1003,7 @@ def load_command_table(self, _):
 
     # region LocalGateways
     with self.command_group('network local-gateway', network_lgw_sdk) as g:
-        g.command('delete', 'begin_delete', supports_no_wait=True)
-        g.show_command('show', 'get')
         g.command('list', 'list', table_transformer=transform_local_gateway_table_output)
-        g.custom_command('create', 'create_local_gateway', supports_no_wait=True, validator=process_local_gateway_create_namespace)
-        g.generic_update_command('update', setter_name='begin_create_or_update', custom_func_name='update_local_gateway', supports_no_wait=True)
-        g.wait_command('wait')
     # endregion
 
     # region NetworkInterfaces: (NIC)
@@ -1097,14 +1042,10 @@ def load_command_table(self, _):
 
     # region NetworkSecurityGroups
     with self.command_group('network nsg', network_nsg_sdk) as g:
-        g.command('delete', 'begin_delete')
-        g.show_command('show', 'get')
-        g.custom_command('list', 'list_nsgs')
         g.custom_command('create', 'create_nsg', transform=transform_nsg_create_output)
         g.generic_update_command('update', setter_name='begin_create_or_update')
 
     with self.command_group('network nsg rule', network_nsg_rule_sdk) as g:
-        g.command('delete', 'begin_delete')
         g.custom_command('list', 'list_nsg_rules', table_transformer=lambda x: [transform_nsg_rule_table_output(i) for i in x])
         g.show_command('show', 'get', table_transformer=transform_nsg_rule_table_output)
         g.custom_command('create', 'create_nsg_rule_2017_06_01', min_api='2017-06-01')
@@ -1257,64 +1198,8 @@ def load_command_table(self, _):
     # endregion
 
     # region RouteFilters
-    with self.command_group('network route-filter', network_rf_sdk, min_api='2016-12-01', is_preview=True) as g:
-        g.custom_command('create', 'create_route_filter', client_factory=cf_route_filters)
-        g.custom_command('list', 'list_route_filters', client_factory=cf_route_filters)
-        g.show_command('show', 'get')
-        g.command('delete', 'begin_delete')
-        g.generic_update_command('update', setter_name='begin_create_or_update', setter_arg_name='route_filter_parameters')
-
-    with self.command_group('network route-filter rule', network_rfr_sdk, min_api='2016-12-01') as g:
-        g.custom_command('create', 'create_route_filter_rule', client_factory=cf_route_filter_rules)
-        g.command('list', 'list_by_route_filter')
-        g.show_command('show', 'get')
-        g.command('delete', 'begin_delete')
-        g.generic_update_command('update', setter_name='begin_create_or_update', setter_arg_name='route_filter_rule_parameters')
-        sc_path = 'azure.mgmt.network.operations#BgpServiceCommunitiesOperations.{}'
-        g.command('list-service-communities', 'list', operations_tmpl=sc_path, client_factory=cf_service_community, table_transformer=transform_service_community_table_output)
-
-    # endregion
-
-    # region RouteTables
-    with self.command_group('network route-table', network_rt_sdk) as g:
-        g.custom_command('create', 'create_route_table', validator=process_route_table_create_namespace)
-        g.command('delete', 'begin_delete')
-        g.show_command('show', 'get')
-        g.custom_command('list', 'list_route_tables')
-        g.generic_update_command('update', setter_name='begin_create_or_update', custom_func_name='update_route_table')
-
-    network_rtr_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.network.operations#RoutesOperations.{}',
-        client_factory=cf_routes
-    )
-    with self.command_group('network route-table route', network_rtr_sdk) as g:
-        g.custom_command('create', 'create_route')
-        g.command('delete', 'begin_delete')
-        g.show_command('show', 'get')
-        g.command('list', 'list')
-        g.generic_update_command('update', setter_name='begin_create_or_update', setter_arg_name='route_parameters', custom_func_name='update_route')
-
-    # endregion
-
-    # region ServiceEndpoint
-    with self.command_group('network service-endpoint', network_endpoint_service_sdk) as g:
-        g.command('list', 'list')
-
-    with self.command_group('network service-endpoint policy', network_sepp_sdk) as g:
-        g.custom_command('create', 'create_service_endpoint_policy')
-        g.command('delete', 'begin_delete')
-        g.custom_command('list', 'list_service_endpoint_policies')
-        g.show_command('show')
-        g.generic_update_command('update', setter_name='begin_create_or_update', custom_func_name='update_service_endpoint_policy')
-
-    with self.command_group('network service-endpoint policy-definition', network_sepd_sdk) as g:
-        g.custom_command('create', 'create_service_endpoint_policy_definition')
-        g.command('delete', 'begin_delete')
-        g.command('list', 'list_by_resource_group')
-        g.show_command('show')
-        g.generic_update_command('update', custom_func_name='update_service_endpoint_policy_definition',
-                                 setter_name='begin_create_or_update',
-                                 setter_arg_name='service_endpoint_policy_definitions')
+    from azure.cli.command_modules.network.aaz.latest.network.route_filter.rule import ListServiceCommunities
+    self.command_table['network route-filter rule list-service-communities'] = ListServiceCommunities(loader=self, table_transformer=transform_service_community_table_output)
     # endregion
 
     # region TrafficManagers
@@ -1517,13 +1402,15 @@ def load_command_table(self, _):
 
     # region Bastion
     with self.command_group('network bastion', network_bastion_hosts_sdk, is_preview=True) as g:
-        g.custom_command('create', 'create_bastion_host')
+        g.custom_command('create', 'create_bastion_host', supports_no_wait=True)
+        g.generic_update_command('update', setter_name='begin_create_or_update', custom_func_name='update_bastion_host', supports_no_wait=True)
         g.show_command('show', 'get')
         g.custom_command('list', 'list_bastion_host')
         g.custom_command('ssh', 'ssh_bastion_host')
         g.custom_command('rdp', 'rdp_bastion_host')
         g.custom_command('tunnel', 'create_bastion_tunnel')
         g.command('delete', 'begin_delete')
+        g.wait_command('wait')
     # endregion
 
     # region PrivateLinkResource and PrivateEndpointConnection
@@ -1537,23 +1424,3 @@ def load_command_table(self, _):
         g.custom_show_command('show', 'show_private_endpoint_connection')
         g.custom_command('list', 'list_private_endpoint_connection')
     # endregion
-
-    # region Network Virtual Appliance
-    with self.command_group('network virtual-appliance', network_virtual_appliances_sdk, client_factory=cf_network_virtual_appliances, is_preview=True) as g:
-        g.custom_command('create', 'create_network_virtual_appliance')
-        g.generic_update_command('update', setter_name='begin_create_or_update', custom_func_name='update_network_virtual_appliance')
-        g.show_command('show', 'get')
-        g.custom_command('list', 'list_network_virtual_appliance')
-        g.command('delete', 'begin_delete', confirmation=True)
-
-    with self.command_group('network virtual-appliance site', virtual_appliance_sites_sdk, client_factory=cf_virtual_appliance_sites, is_preview=True) as g:
-        g.custom_command('create', 'create_network_virtual_appliance_site')
-        g.generic_update_command('update', setter_name='begin_create_or_update', custom_func_name='update_network_virtual_appliance_site')
-        g.show_command('show', 'get')
-        g.command('delete', 'begin_delete', confirmation=True)
-        g.command('list', 'list')
-
-    with self.command_group('network virtual-appliance sku', virtual_appliance_skus_sdk, is_preview=True) as g:
-        g.show_command('show', 'get')
-        g.command('list', 'list')
-    # endregion
