@@ -30,6 +30,7 @@ def register_providers():
     _register_one_provider('Microsoft.DBforMariaDB/servers', '2018-06-01', False)
     _register_one_provider('Microsoft.DBforPostgreSQL/servers', '2018-06-01', False, '2017-12-01-preview')
     _register_one_provider('Microsoft.Devices/IotHubs', '2020-03-01', True)
+    _register_one_provider('Microsoft.DeviceUpdate/accounts', '2020-03-01-preview', True)
     _register_one_provider('Microsoft.DocumentDB/databaseAccounts', '2019-08-01-preview', False, '2020-03-01')
     _register_one_provider('Microsoft.DigitalTwins/digitalTwinsInstances', '2020-12-01', True)
     _register_one_provider('Microsoft.EventGrid/topics', '2020-04-01-preview', True)
@@ -66,6 +67,7 @@ def register_providers():
     _register_one_provider('Microsoft.RecoveryServices/vaults', '2021-07-01', True)
     _register_one_provider('Microsoft.Kusto/clusters', '2021-08-27', True)
     _register_one_provider("Microsoft.KubernetesConfiguration/privateLinkScopes", '2022-04-02-preview', True)
+    _register_one_provider("Microsoft.OpenEnergyPlatform/energyServices", '2022-04-04-preview', True)
 
 
 def _register_one_provider(provider, api_version, support_list_or_not, resource_get_api_version=None, support_connection_operation=True):  # pylint: disable=line-too-long
