@@ -16,7 +16,7 @@ from azure.cli.core.commands.parameters import (
     get_three_state_flag)
 from azure.cli.command_modules.rdbms.validators import configuration_value_validator, validate_subnet, \
     tls_validator, public_access_validator, maintenance_window_validator, ip_address_validator, \
-    retention_validator, firewall_rule_name_validator
+    retention_validator, firewall_rule_name_validator, validate_identity, validate_byok_identity, validate_identities
 from azure.cli.core.local_context import LocalContextAttribute, LocalContextAction
 
 from .randomname.generate import generate_username
@@ -89,7 +89,11 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             c.argument('assign_identity', options_list=['--assign-identity'], help='Generate and assign an Azure Active Directory Identity for this server for use with key management services like Azure KeyVault.')
 
             c.argument('location', arg_type=get_location_type(self.cli_ctx))
-            c.argument('version', help='Server major version.')
+            if command_group == 'postgres':
+                c.argument('version', default='11',
+                           help='Server major version. https://docs.microsoft.com/en-us/azure/postgresql/single-server/concepts-supported-versions')
+            else:
+                c.argument('version', help='Server major version.')
 
         with self.argument_context('{} server update'.format(command_group)) as c:
             c.ignore('family', 'capacity', 'tier')
@@ -215,7 +219,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
     _complex_params('postgres')
 
     # Flexible-server
-    # pylint: disable=too-many-statements, too-many-locals
+    # pylint: disable=too-many-statements, too-many-locals, too-many-branches
     def _flexible_server_params(command_group):
 
         server_name_arg_type = CLIArgumentType(
@@ -270,7 +274,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
 
         sku_name_arg_type = CLIArgumentType(
             options_list=['--sku-name'],
-            help='The name of the compute SKU. Follows the convention Standard_{VM name}. Examples: Standard_D4s_v3'
+            help='The name of the compute SKU. Follows the convention Standard_{VM name}. Examples: Standard_B1ms'
         )
 
         storage_gb_arg_type = CLIArgumentType(
@@ -364,20 +368,19 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             help="The availability zone information of the standby server when high availability is enabled."
         )
 
-        pg_high_availability_arg_type = CLIArgumentType(
-            arg_type=get_enum_type(['Enabled', 'Disabled']),
-            options_list=['--high-availability'],
-            help='Enable or disable high availability feature. '
-                 'Default value is Disabled. High availability can only be set during flexible server create time'
-        )
-
-        mysql_high_availability_arg_type = CLIArgumentType(
+        high_availability_arg_type = CLIArgumentType(
             arg_type=get_enum_type(['ZoneRedundant', 'SameZone', 'Disabled', 'Enabled']),
             options_list=['--high-availability'],
             help='Enable (ZoneRedundant or SameZone) or disable high availability feature. '
                  'Default value is Disabled. High availability can only be set during flexible server create time. '
         )
 
+        mysql_version_upgrade_arg_type = CLIArgumentType(
+            arg_type=get_enum_type(['8']),
+            options_list=['--version', '-v'],
+            help='Server major version.'
+        )
+
         private_dns_zone_arguments_arg_type = CLIArgumentType(
             options_list=['--private-dns-zone'],
             help='This parameter only applies for a server with private access. '
@@ -405,6 +408,41 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             help='Whether or not geo redundant backup is enabled.'
         )
 
+        identity_arg_type = CLIArgumentType(
+            options_list=['--identity'],
+            help='The name or resource ID of the user assigned identity for data encryption.',
+            validator=validate_byok_identity
+        )
+
+        backup_identity_arg_type = CLIArgumentType(
+            options_list=['--backup-identity'],
+            help='The name or resource ID of the geo backup user identity for data encryption. The identity needs to be in the same region as the backup region.',
+            validator=validate_byok_identity
+        )
+
+        key_arg_type = CLIArgumentType(
+            options_list=['--key'],
+            help='The resource ID of the primary keyvault key for data encryption.'
+        )
+
+        backup_key_arg_type = CLIArgumentType(
+            options_list=['--backup-key'],
+            help='The resource ID of the geo backup keyvault key for data encryption. The key needs to be in the same region as the backup region.'
+        )
+
+        disable_data_encryption_arg_type = CLIArgumentType(
+            options_list=['--disable-data-encryption'],
+            arg_type=get_three_state_flag(),
+            help='Disable data encryption by removing key(s).'
+        )
+
+        identities_arg_type = CLIArgumentType(
+            options_list=['--identity', '-n'],
+            nargs='+',
+            help='Space-separated names or ID\'s of identities.',
+            validator=validate_identities
+        )
+
         with self.argument_context('{} flexible-server'.format(command_group)) as c:
             c.argument('resource_group_name', arg_type=resource_group_name_type)
             c.argument('server_name', arg_type=server_name_arg_type)
@@ -416,7 +454,6 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('sku_name', default='Standard_D2s_v3', arg_type=sku_name_arg_type)
                 c.argument('storage_gb', default='128', arg_type=storage_gb_arg_type)
                 c.argument('version', default='13', arg_type=version_arg_type)
-                c.argument('high_availability', arg_type=pg_high_availability_arg_type, default="Disabled")
                 c.argument('backup_retention', default=7, arg_type=pg_backup_retention_arg_type)
             elif command_group == 'mysql':
                 c.argument('tier', default='Burstable', arg_type=tier_arg_type)
@@ -425,12 +462,16 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('version', default='5.7', arg_type=version_arg_type)
                 c.argument('iops', arg_type=iops_arg_type)
                 c.argument('auto_grow', default='Enabled', arg_type=auto_grow_arg_type)
-                c.argument('high_availability', arg_type=mysql_high_availability_arg_type, default="Disabled")
                 c.argument('backup_retention', default=7, arg_type=mysql_backup_retention_arg_type)
                 c.argument('geo_redundant_backup', default='Disabled', arg_type=geo_redundant_backup_arg_type)
+                c.argument('byok_identity', arg_type=identity_arg_type)
+                c.argument('backup_byok_identity', arg_type=backup_identity_arg_type)
+                c.argument('byok_key', arg_type=key_arg_type)
+                c.argument('backup_byok_key', arg_type=backup_key_arg_type)
             c.argument('location', arg_type=get_location_type(self.cli_ctx))
             c.argument('administrator_login', default=generate_username(), arg_type=administrator_login_arg_type)
             c.argument('administrator_login_password', arg_type=administrator_login_password_arg_type)
+            c.argument('high_availability', arg_type=high_availability_arg_type, default="Disabled")
             c.argument('public_access', arg_type=public_access_arg_type)
             c.argument('vnet', arg_type=vnet_arg_type)
             c.argument('vnet_address_prefix', arg_type=vnet_address_prefix_arg_type)
@@ -484,17 +525,26 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             c.argument('sku_name', arg_type=sku_name_arg_type)
             c.argument('storage_gb', arg_type=storage_gb_arg_type)
             c.argument('standby_availability_zone', arg_type=standby_availability_zone_arg_type)
+            c.argument('high_availability', arg_type=high_availability_arg_type)
             if command_group == 'mysql':
                 c.argument('auto_grow', arg_type=auto_grow_arg_type)
                 c.argument('replication_role', options_list=['--replication-role'],
                            help='The replication role of the server.')
                 c.argument('iops', arg_type=iops_arg_type)
-                c.argument('high_availability', arg_type=mysql_high_availability_arg_type)
                 c.argument('backup_retention', arg_type=mysql_backup_retention_arg_type)
+                c.argument('byok_identity', arg_type=identity_arg_type)
+                c.argument('backup_byok_identity', arg_type=backup_identity_arg_type)
+                c.argument('byok_key', arg_type=key_arg_type)
+                c.argument('backup_byok_key', arg_type=backup_key_arg_type)
+                c.argument('disable_data_encryption', arg_type=disable_data_encryption_arg_type)
             elif command_group == 'postgres':
-                c.argument('high_availability', arg_type=pg_high_availability_arg_type)
                 c.argument('backup_retention', arg_type=pg_backup_retention_arg_type)
 
+        if command_group == 'mysql':
+            with self.argument_context('{} flexible-server upgrade'.format(command_group)) as c:
+                c.argument('version', arg_type=mysql_version_upgrade_arg_type)
+                c.argument('yes', arg_type=yes_arg_type)
+
         with self.argument_context('{} flexible-server restart'.format(command_group)) as c:
             if command_group == 'postgres':
                 c.argument('fail_over', options_list=['--failover'],
@@ -607,15 +657,50 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         # logs
         if command_group == 'mysql':
             with self.argument_context('{} flexible-server server-logs download'.format(command_group)) as c:
-                c.argument('server_name', id_part='name', options_list=['--server-name', '-s'], arg_type=server_name_arg_type, help='Name of the Server.')
+                c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
                 c.argument('file_name', options_list=['--name', '-n'], nargs='+', help='Space-separated list of log filenames on the server to download.')
 
             with self.argument_context('{} flexible-server server-logs list'.format(command_group)) as c:
-                c.argument('server_name', id_part='name', options_list=['--server-name', '-s'], arg_type=server_name_arg_type, help='Name of the Server.')
+                c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
                 c.argument('filename_contains', help='The pattern that file name should match.')
                 c.argument('file_last_written', type=int, help='Integer in hours to indicate file last modify time.', default=72)
                 c.argument('max_file_size', type=int, help='The file size limitation to filter files.')
 
+        # backups
+        if command_group == 'mysql':
+            with self.argument_context('{} flexible-server backup create'.format(command_group)) as c:
+                c.argument('backup_name', options_list=['--backup-name', '-b'], help='The name of the new backup.')
+
+        with self.argument_context('{} flexible-server backup show'.format(command_group)) as c:
+            c.argument('backup_name', id_part='child_name_1', options_list=['--backup-name', '-b'], help='The name of the backup.')
+
+        with self.argument_context('{} flexible-server backup list'.format(command_group)) as c:
+            c.argument('server_name', id_part=None, arg_type=server_name_arg_type)
+
+        # identity
+        if command_group == 'mysql':
+            with self.argument_context('{} flexible-server identity'.format(command_group)) as c:
+                c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
+
+            with self.argument_context('{} flexible-server identity assign'.format(command_group)) as c:
+                c.argument('identities', arg_type=identities_arg_type)
+
+            with self.argument_context('{} flexible-server identity remove'.format(command_group)) as c:
+                c.argument('identities', arg_type=identities_arg_type)
+
+            with self.argument_context('{} flexible-server identity show'.format(command_group)) as c:
+                c.argument('identity', options_list=['--identity', '-n'], help='Name or ID of identity to show.', validator=validate_identity)
+
+        # ad-admin
+        if command_group == 'mysql':
+            with self.argument_context('{} flexible-server ad-admin'.format(command_group)) as c:
+                c.argument('server_name', id_part=None, options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
+
+            with self.argument_context('{} flexible-server ad-admin create'.format(command_group)) as c:
+                c.argument('login', options_list=['--display-name', '-u'], help='Display name of the Azure AD administrator user or group.')
+                c.argument('sid', options_list=['--object-id', '-i'], help='The unique ID of the Azure AD administrator.')
+                c.argument('identity', help='Name or ID of identity used for AAD Authentication.', validator=validate_identity)
+
         handle_migration_parameters(command_group, server_name_arg_type, migration_id_arg_type)
 
     def handle_migration_parameters(command_group, server_name_arg_type, migration_id_arg_type):
