@@ -15,9 +15,12 @@ from azure.cli.core.util import CLIError, sdk_no_wait, user_confirmation
 from azure.cli.core.local_context import ALL
 from azure.mgmt.rdbms import mysql_flexibleservers
 from ._client_factory import get_mysql_flexible_management_client, cf_mysql_flexible_firewall_rules, \
-    cf_mysql_flexible_db, cf_mysql_check_resource_availability, cf_mysql_flexible_private_dns_zone_suffix_operations
+    cf_mysql_flexible_db, cf_mysql_check_resource_availability, \
+    cf_mysql_check_resource_availability_without_location, cf_mysql_flexible_private_dns_zone_suffix_operations, \
+    cf_mysql_flexible_servers, cf_mysql_flexible_replica
 from ._flexible_server_util import resolve_poller, generate_missing_parameters, get_mysql_list_skus_info, \
-    generate_password, parse_maintenance_window, replace_memory_optimized_tier
+    generate_password, parse_maintenance_window, replace_memory_optimized_tier, build_identity_and_data_encryption, \
+    get_identity_and_data_encryption
 from .flexible_server_custom_common import create_firewall_rule
 from .flexible_server_virtual_network import prepare_private_network, prepare_private_dns_zone, prepare_public_network
 from .validators import mysql_arguments_validator, validate_mysql_replica, validate_server_name, validate_georestore_location, \
@@ -42,14 +45,18 @@ def flexible_server_create(cmd, client,
                            subnet=None, subnet_address_prefix=None, vnet=None, vnet_address_prefix=None,
                            private_dns_zone_arguments=None, public_access=None,
                            high_availability=None, zone=None, standby_availability_zone=None,
-                           iops=None, auto_grow=None, geo_redundant_backup=None, yes=False):
+                           iops=None, auto_grow=None, geo_redundant_backup=None,
+                           byok_identity=None, backup_byok_identity=None, byok_key=None, backup_byok_key=None,
+                           yes=False):
     # Generate missing parameters
     location, resource_group_name, server_name = generate_missing_parameters(cmd, location, resource_group_name,
                                                                              server_name, 'mysql')
     db_context = DbContext(
         cmd=cmd, cf_firewall=cf_mysql_flexible_firewall_rules, cf_db=cf_mysql_flexible_db,
-        cf_availability=cf_mysql_check_resource_availability, cf_private_dns_zone_suffix=cf_mysql_flexible_private_dns_zone_suffix_operations, logging_name='MySQL', command_group='mysql', server_client=client,
-        location=location)
+        cf_availability=cf_mysql_check_resource_availability,
+        cf_availability_without_location=cf_mysql_check_resource_availability_without_location,
+        cf_private_dns_zone_suffix=cf_mysql_flexible_private_dns_zone_suffix_operations,
+        logging_name='MySQL', command_group='mysql', server_client=client, location=location)
 
     # Process parameters
     server_name = server_name.lower()
@@ -74,7 +81,11 @@ def flexible_server_create(cmd, client,
                               public_access=public_access,
                               auto_grow=auto_grow,
                               version=version,
-                              geo_redundant_backup=geo_redundant_backup)
+                              geo_redundant_backup=geo_redundant_backup,
+                              byok_identity=byok_identity,
+                              backup_byok_identity=backup_byok_identity,
+                              byok_key=byok_key,
+                              backup_byok_key=backup_byok_key)
     list_skus_info = get_mysql_list_skus_info(db_context.cmd, location)
     iops_info = list_skus_info['iops_info']
 
@@ -114,11 +125,14 @@ def flexible_server_create(cmd, client,
 
     administrator_login_password = generate_password(administrator_login_password)
 
+    identity, data_encryption = build_identity_and_data_encryption(byok_identity, backup_byok_identity, byok_key, backup_byok_key)
+
     # Create mysql server
     # Note : passing public_access has no effect as the accepted values are 'Enabled' and 'Disabled'. So the value ends up being ignored.
     server_result = _create_server(db_context, cmd, resource_group_name, server_name,
                                    tags=tags,
                                    location=location,
+                                   identity=identity,
                                    sku=sku,
                                    administrator_login=administrator_login,
                                    administrator_login_password=administrator_login_password,
@@ -127,7 +141,8 @@ def flexible_server_create(cmd, client,
                                    network=network,
                                    version=version,
                                    high_availability=high_availability,
-                                   availability_zone=zone)
+                                   availability_zone=zone,
+                                   data_encryption=data_encryption)
 
     # Adding firewall rule
     if start_ip != -1 and end_ip != -1:
@@ -189,23 +204,30 @@ def flexible_server_restore(cmd, client,
         location = ''.join(source_server_object.location.lower().split())
 
         db_context = DbContext(
-            cmd=cmd, cf_availability=cf_mysql_check_resource_availability, logging_name='MySQL', command_group='mysql', server_client=client,
-            location=location)
+            cmd=cmd, cf_availability=cf_mysql_check_resource_availability,
+            cf_availability_without_location=cf_mysql_check_resource_availability_without_location,
+            logging_name='MySQL', command_group='mysql', server_client=client, location=location)
         validate_server_name(db_context, server_name, provider + '/flexibleServers')
 
+        identity, data_encryption = get_identity_and_data_encryption(source_server_object)
+
         parameters = mysql_flexibleservers.models.Server(
             location=location,
+            identity=identity,
             restore_point_in_time=restore_point_in_time,
             source_server_resource_id=source_server_id,  # this should be the source server name, not id
             create_mode="PointInTimeRestore",
-            availability_zone=zone
+            availability_zone=zone,
+            data_encryption=data_encryption
         )
 
         if any((public_access, vnet, subnet)):
             db_context = DbContext(
                 cmd=cmd, cf_firewall=cf_mysql_flexible_firewall_rules, cf_db=cf_mysql_flexible_db,
-                cf_availability=cf_mysql_check_resource_availability, cf_private_dns_zone_suffix=cf_mysql_flexible_private_dns_zone_suffix_operations, logging_name='MySQL', command_group='mysql', server_client=client,
-                location=location)
+                cf_availability=cf_mysql_check_resource_availability,
+                cf_availability_without_location=cf_mysql_check_resource_availability_without_location,
+                cf_private_dns_zone_suffix=cf_mysql_flexible_private_dns_zone_suffix_operations,
+                logging_name='MySQL', command_group='mysql', server_client=client, location=location)
 
             parameters.network, _, _ = flexible_server_provision_network_resource(cmd=cmd,
                                                                                   resource_group_name=resource_group_name,
@@ -255,18 +277,24 @@ def flexible_server_georestore(cmd, client,
 
         db_context = DbContext(
             cmd=cmd, cf_firewall=cf_mysql_flexible_firewall_rules, cf_db=cf_mysql_flexible_db,
-            cf_availability=cf_mysql_check_resource_availability, cf_private_dns_zone_suffix=cf_mysql_flexible_private_dns_zone_suffix_operations, logging_name='MySQL', command_group='mysql', server_client=client,
-            location=source_server_object.location)
+            cf_availability=cf_mysql_check_resource_availability,
+            cf_availability_without_location=cf_mysql_check_resource_availability_without_location,
+            cf_private_dns_zone_suffix=cf_mysql_flexible_private_dns_zone_suffix_operations,
+            logging_name='MySQL', command_group='mysql', server_client=client, location=source_server_object.location)
 
         validate_server_name(db_context, server_name, provider + '/flexibleServers')
         validate_georestore_location(db_context, location)
         validate_georestore_network(source_server_object, public_access, vnet, subnet)
 
+        identity, data_encryption = get_identity_and_data_encryption(source_server_object)
+
         parameters = mysql_flexibleservers.models.Server(
             location=location,
             source_server_resource_id=source_server_id,  # this should be the source server name, not id
             create_mode="GeoRestore",
-            availability_zone=zone
+            availability_zone=zone,
+            identity=identity,
+            data_encryption=data_encryption
         )
 
         db_context.location = location
@@ -305,13 +333,16 @@ def flexible_server_update_custom_func(cmd, client, instance,
                                        standby_availability_zone=None,
                                        maintenance_window=None,
                                        tags=None,
-                                       replication_role=None):
+                                       replication_role=None,
+                                       byok_identity=None, backup_byok_identity=None, byok_key=None, backup_byok_key=None,
+                                       disable_data_encryption=False):
     # validator
     location = ''.join(instance.location.lower().split())
     db_context = DbContext(
         cmd=cmd, cf_firewall=cf_mysql_flexible_firewall_rules, cf_db=cf_mysql_flexible_db,
-        cf_availability=cf_mysql_check_resource_availability, logging_name='MySQL', command_group='mysql', server_client=client,
-        location=instance.location)
+        cf_availability=cf_mysql_check_resource_availability,
+        cf_availability_without_location=cf_mysql_check_resource_availability_without_location,
+        logging_name='MySQL', command_group='mysql', server_client=client, location=instance.location)
 
     if high_availability and high_availability.lower() == 'enabled':
         logger.warning('\'Enabled\' value for high availability parameter will be deprecated. Please use \'ZoneRedundant\' or \'SameZone\' instead.')
@@ -331,7 +362,13 @@ def flexible_server_update_custom_func(cmd, client, instance,
                               standby_availability_zone=standby_availability_zone,
                               auto_grow=auto_grow,
                               replication_role=replication_role,
-                              instance=instance)
+                              instance=instance,
+                              geo_redundant_backup=instance.backup.geo_redundant_backup,
+                              byok_identity=byok_identity,
+                              backup_byok_identity=backup_byok_identity,
+                              byok_key=byok_key,
+                              backup_byok_key=backup_byok_key,
+                              disable_data_encryption=disable_data_encryption)
 
     list_skus_info = get_mysql_list_skus_info(db_context.cmd, location)
     iops_info = list_skus_info['iops_info']
@@ -377,6 +414,27 @@ def flexible_server_update_custom_func(cmd, client, instance,
         else:
             instance.high_availability = mysql_flexibleservers.models.HighAvailability(mode=high_availability)
 
+    identity, data_encryption = build_identity_and_data_encryption(byok_identity, backup_byok_identity, byok_key, backup_byok_key)
+    if disable_data_encryption:
+        data_encryption = mysql_flexibleservers.models.DataEncryption(type="SystemManaged")
+
+    if disable_data_encryption or byok_key:
+        server_operations_client = cf_mysql_flexible_servers(cmd.cli_ctx, '_')
+        replica_operations_client = cf_mysql_flexible_replica(cmd.cli_ctx, '_')
+
+        from azure.cli.core.util import parse_proxy_resource_id
+        resource_group_name = parse_proxy_resource_id(instance.id)['resource_group']
+
+        replicas = replica_operations_client.list_by_server(resource_group_name, instance.name)
+        for replica in replicas:
+            resolve_poller(
+                server_operations_client.begin_update(
+                    resource_group_name=resource_group_name,
+                    server_name=replica.name,
+                    parameters=ServerForUpdate(identity=identity, data_encryption=data_encryption)),
+                cmd.cli_ctx, 'Updating data encryption to replica {}'.format(replica.name)
+            )
+
     if storage_gb:
         instance.storage.storage_size_gb = storage_gb
 
@@ -396,7 +454,9 @@ def flexible_server_update_custom_func(cmd, client, instance,
                              backup=instance.backup,
                              administrator_login_password=administrator_login_password,
                              high_availability=instance.high_availability,
-                             tags=tags)
+                             tags=tags,
+                             identity=identity,
+                             data_encryption=data_encryption)
 
     return params
 
@@ -528,11 +588,15 @@ def flexible_replica_create(cmd, client, resource_group_name, source_server, rep
     if not zone:
         zone = source_server_object.availability_zone
 
+    identity, data_encryption = get_identity_and_data_encryption(source_server_object)
+
     parameters = mysql_flexibleservers.models.Server(
         sku=mysql_flexibleservers.models.Sku(name=sku_name, tier=tier),
         source_server_resource_id=source_server_id,
         location=location,
         availability_zone=zone,
+        identity=identity,
+        data_encryption=data_encryption,
         create_mode="Replica")
 
     return sdk_no_wait(no_wait, client.begin_create, resource_group_name, replica_name, parameters)
@@ -569,7 +633,7 @@ def flexible_list_skus(cmd, client, location):
 
 
 def _create_server(db_context, cmd, resource_group_name, server_name, tags, location, sku, administrator_login, administrator_login_password,
-                   storage, backup, network, version, high_availability, availability_zone):
+                   storage, backup, network, version, high_availability, availability_zone, identity, data_encryption):
     logging_name, server_client = db_context.logging_name, db_context.server_client
     logger.warning('Creating %s Server \'%s\' in group \'%s\'...', logging_name, server_name, resource_group_name)
 
@@ -580,6 +644,7 @@ def _create_server(db_context, cmd, resource_group_name, server_name, tags, loca
     parameters = mysql_flexibleservers.models.Server(
         tags=tags,
         location=location,
+        identity=identity,
         sku=sku,
         administrator_login=administrator_login,
         administrator_login_password=administrator_login_password,
@@ -589,6 +654,7 @@ def _create_server(db_context, cmd, resource_group_name, server_name, tags, loca
         version=version,
         high_availability=high_availability,
         availability_zone=availability_zone,
+        data_encryption=data_encryption,
         create_mode="Create")
 
     return resolve_poller(
@@ -741,12 +807,14 @@ def get_free_iops(storage_in_mb, iops_info, tier, sku_name):
 # pylint: disable=too-many-instance-attributes, too-few-public-methods, useless-object-inheritance
 class DbContext(object):
     def __init__(self, cmd=None, azure_sdk=None, logging_name=None, cf_firewall=None, cf_db=None,
-                 cf_availability=None, cf_private_dns_zone_suffix=None, command_group=None, server_client=None, location=None):
+                 cf_availability=None, cf_availability_without_location=None, cf_private_dns_zone_suffix=None,
+                 command_group=None, server_client=None, location=None):
         self.cmd = cmd
         self.azure_sdk = azure_sdk
         self.cf_firewall = cf_firewall
         self.cf_db = cf_db
         self.cf_availability = cf_availability
+        self.cf_availability_without_location = cf_availability_without_location
         self.cf_private_dns_zone_suffix = cf_private_dns_zone_suffix
         self.logging_name = logging_name
         self.command_group = command_group
