@@ -84,30 +84,32 @@ examples:
 
 helps['ad app credential'] = """
 type: group
-short-summary: manage an application's password or certificate credentials
+short-summary: Manage an application's password or certificate credentials
 """
 
 helps['ad app credential delete'] = """
 type: command
-short-summary: delete an application's password or certificate credentials
+short-summary: Delete an application's password or certificate credentials
 examples:
-  - name: delete an application's password or certificate credentials (autogenerated)
-    text: az ad app credential delete --id 00000000-0000-0000-0000-000000000000 --key-id xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx
-    crafted: true
+- name: Delete an application's password credentials
+  text: az ad app credential delete --id 00000000-0000-0000-0000-000000000000 --key-id xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx
+- name: Delete an application's certificate credentials
+  text: az ad app credential delete --id 00000000-0000-0000-0000-000000000000 --key-id xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx --cert
 """
 
 helps['ad app credential list'] = """
 type: command
 short-summary: List an application's password or certificate credential metadata. (The content of the password or certificate credential is not retrievable.)
 examples:
-  - name: list an application's password or certificate credentials (autogenerated)
-    text: az ad app credential list --id 00000000-0000-0000-0000-000000000000
-    crafted: true
+- name: List an application's password credentials
+  text: az ad app credential list --id 00000000-0000-0000-0000-000000000000
+- name: List an application's certificate credentials
+  text: az ad app credential list --id 00000000-0000-0000-0000-000000000000 --cert
 """
 
 helps['ad app credential reset'] = """
 type: command
-short-summary: Append or overwrite an application's password or certificate credentials
+short-summary: Reset an application's password or certificate credentials
 long-summary: >-
     By default, this command clears all passwords and keys, and let graph service generate a password credential.
 
@@ -116,18 +118,19 @@ long-summary: >-
     in your code or check the credentials into your source control. As an alternative, consider using
     [managed identities](https://aka.ms/azadsp-managed-identities) if available to avoid the need to use credentials.
 examples:
-  - name: Append a certificate to the application with the certificate string.
-    text: az ad app credential reset --id 00000000-0000-0000-0000-000000000000 --cert "MIICoT..." --append
-  - name: Append a certificate to the application with the certificate file.
-    text: |-
-        az ad app credential reset --id 00000000-0000-0000-0000-000000000000 --cert "@~/cert.pem" --append
-        `cert.pem` contains the following content
-        -----BEGIN CERTIFICATE-----  <<< this line is optional
-        MIICoT...
-        -----END CERTIFICATE-----    <<< this line is optional
-  - name: append or overwrite an application's password or certificate credentials (autogenerated)
-    text: az ad app credential reset --id 00000000-0000-0000-0000-000000000000
-    crafted: true
+- name: Reset an application's credential with a password
+  text: az ad app credential reset --id 00000000-0000-0000-0000-000000000000
+- name: Reset an application's credential with a new self-signed certificate
+  text: az ad app credential reset --id 00000000-0000-0000-0000-000000000000 --create-cert
+- name: Append a certificate to the application with the certificate string.
+  text: az ad app credential reset --id 00000000-0000-0000-0000-000000000000 --cert "MIICoT..." --append
+- name: Append a certificate to the application with the certificate file.
+  text: |-
+      az ad app credential reset --id 00000000-0000-0000-0000-000000000000 --cert "@~/cert.pem" --append
+      `cert.pem` contains the following content
+      -----BEGIN CERTIFICATE-----  <<< this line is optional
+      MIICoT...
+      -----END CERTIFICATE-----    <<< this line is optional
 """
 
 helps['ad app delete'] = """
@@ -489,24 +492,6 @@ long-summary: >-
     You may use --role and --scopes to assign a specific role and narrow the scope to a resource or resource group.
     You may also use `az role assignment create` to create role assignments for this service principal later.
     See [steps to add a role assignment](https://aka.ms/azadsp-more) for more information.
-parameters:
-  - name: --cert
-    short-summary: Certificate to use for credentials.
-    long-summary: When used with `--keyvault,` indicates the name of the cert to use or create. Otherwise, supply a PEM or DER formatted public certificate string. Use `@{path}` to load from a file. Do not include private key info.
-  - name: --create-cert
-    short-summary: Create a self-signed certificate to use for the credential. Only the current OS user has read/write permission to this certificate.
-    long-summary: Use with `--keyvault` to create the certificate in Key Vault. Otherwise, a certificate will be created locally.
-  - name: --keyvault
-    short-summary: Name or ID of a KeyVault to use for creating or retrieving certificates.
-  - name: --years
-    short-summary: 'Number of years for which the credentials will be valid. Default: 1 year'
-  - name: --scopes
-    short-summary: >
-        Space-separated list of scopes the service principal's role assignment applies to.
-        e.g., /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup,
-        /subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup/providers/Microsoft.Compute/virtualMachines/myVM
-  - name: --role
-    short-summary: Role of the service principal.
 examples:
   - name: Create without role assignment.
     text: az ad sp create-for-rbac
@@ -524,62 +509,53 @@ examples:
 
 helps['ad sp credential'] = """
 type: group
-short-summary: Manage a service principal's credentials.
-long-summary: The credential update will be applied on the Application object the service principal is associated with. In other words, you can accomplish the same thing using "az ad app credential"
+short-summary: Manage a service principal's password or certificate credentials
 """
 
 helps['ad sp credential delete'] = """
 type: command
-short-summary: Delete a service principal's credential.
+short-summary: Delete a service principal's password or certificate credentials
 examples:
-  - name: Delete a service principal's credential. (autogenerated)
-    text: az ad sp credential delete --id 00000000-0000-0000-0000-000000000000 --key-id xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx
-    crafted: true
+- name: Delete a service principal's password credential
+  text: az ad sp credential delete --id 00000000-0000-0000-0000-000000000000 --key-id xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx
+- name: Delete a service principal's certificate credential
+  text: az ad sp credential delete --id 00000000-0000-0000-0000-000000000000 --key-id xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx --cert
 """
 
 helps['ad sp credential list'] = """
 type: command
-short-summary: List a service principal's credentials.
+short-summary: List a service principal's password or certificate credential metadata. (The content of the password or certificate credential is not retrievable.)
 examples:
-  - name: List a service principal's credentials. (autogenerated)
-    text: az ad sp credential list --id 00000000-0000-0000-0000-000000000000
-    crafted: true
+- name: List a service principal's password credentials
+  text: az ad sp credential list --id 00000000-0000-0000-0000-000000000000
+- name: List a service principal's certificate credentials
+  text: az ad sp credential list --id 00000000-0000-0000-0000-000000000000 --cert
 """
 
 helps['ad sp credential reset'] = """
 type: command
-short-summary: Reset a service principal credential.
+short-summary: Reset a service principal's password or certificate credentials
 long-summary: >-
-    Use upon expiration of the service principal's credentials, or in the event that login credentials are lost.
+    By default, this command clears all passwords and keys, and let graph service generate a password credential.
 
 
     The output includes credentials that you must protect. Be sure that you do not include these credentials
     in your code or check the credentials into your source control. As an alternative, consider using
     [managed identities](https://aka.ms/azadsp-managed-identities) if available to avoid the need to use credentials.
-parameters:
-  - name: --cert
-    short-summary: Certificate to use for credentials.
-    long-summary: When using `--keyvault,` indicates the name of the cert to use or create. Otherwise, supply a PEM or DER formatted public certificate string. Use `@{path}` to load from a file. Do not include private key info.
-  - name: --create-cert
-    short-summary: Create a self-signed certificate to use for the credential.
-    long-summary: Use with `--keyvault` to create the certificate in Key Vault. Otherwise, a certificate will be created locally.
-  - name: --keyvault
-    short-summary: Name or ID of a KeyVault to use for creating or retrieving certificates.
-  - name: --years
-    short-summary: 'Number of years for which the credentials will be valid. Default: 1 year'
 examples:
-  - name: Append a certificate to the service principal with the certificate string.
-    text: az ad sp credential reset --id myapp --cert "MIICoT..." --append
-  - name: Append a certificate to the service principal with the certificate file.
-    text: |-
-        az ad sp credential reset --id myapp --cert "@~/cert.pem" --append
-        `cert.pem` contains the following content
-        -----BEGIN CERTIFICATE-----  <<< this line is optional
-        MIICoT...
-        -----END CERTIFICATE-----    <<< this line is optional
-  - name: Reset a service principal credential. (autogenerated)
-    text: az ad sp credential reset --id MyAppURIForCredential
-    crafted: true
+- name: Reset a service principal's credential with a password
+  text: az ad sp credential reset --id 00000000-0000-0000-0000-000000000000
+- name: Reset a service principal's credential with a new self-signed certificate
+  text: az ad sp credential reset --id 00000000-0000-0000-0000-000000000000 --create-cert
+- name: Append a certificate to the service principal with the certificate string.
+  text: az ad sp credential reset --id 00000000-0000-0000-0000-000000000000 --cert "MIICoT..." --append
+- name: Append a certificate to the service principal with the certificate file.
+  text: |-
+      az ad sp credential reset --id 00000000-0000-0000-0000-000000000000 --cert "@~/cert.pem" --append
+      `cert.pem` contains the following content
+      -----BEGIN CERTIFICATE-----  <<< this line is optional
+      MIICoT...
+      -----END CERTIFICATE-----    <<< this line is optional
 """
 
 helps['ad sp delete'] = """
