@@ -73,23 +73,23 @@ def load_arguments(self, _):
                         'Specifies the URLs where user tokens are sent for sign-in, or the redirect URIs '
                         'where OAuth 2.0 authorization codes and access tokens are sent.')
 
-        # keyCredentials
-        c.argument('start_date', arg_group='keyCredentials',
+        # keyCredential
+        c.argument('start_date', arg_group='keyCredential',
                    help="Date or datetime at which credentials become valid (e.g. '2017-01-01T01:00:00+00:00' or "
                         "'2017-01-01'). Default value is current time")
-        c.argument('end_date', arg_group='keyCredentials',
+        c.argument('end_date', arg_group='keyCredential',
                    help="Date or datetime after which credentials expire (e.g. '2017-12-31T11:59:59+00:00' or "
                         "'2017-12-31'). Default value is one year after current time")
-        c.argument('key_value', arg_group='keyCredentials',
+        c.argument('key_value', arg_group='keyCredential',
                    help='the value for the key credentials associated with the application')
-        c.argument('key_type', arg_group='keyCredentials',
+        c.argument('key_type', arg_group='keyCredential',
                    help='the type of the key credentials associated with the application',
                    arg_type=get_enum_type(['AsymmetricX509Cert', 'Password', 'Symmetric'],
                                           default='AsymmetricX509Cert'))
-        c.argument('key_usage', arg_group='keyCredentials',
+        c.argument('key_usage', arg_group='keyCredential',
                    help='the usage of the key credentials associated with the application.',
                    arg_type=get_enum_type(['Sign', 'Verify'], default='Verify'))
-        c.argument('key_display_name', arg_group='keyCredentials',
+        c.argument('key_display_name', arg_group='keyCredential',
                    help="Friendly name for the key.")
 
         # JSON properties
@@ -171,8 +171,12 @@ def load_arguments(self, _):
         c.argument('display_name', options_list=['--display-name', '--name', '-n'],
                    help='Display name of the service principal. If not present, default to azure-cli-%Y-%m-%d-%H-%M-%S '
                         'where the suffix is the time of creation.')
-        c.argument('scopes', nargs='+')
-        c.argument('role', completer=get_role_definition_name_completion_list)
+        c.argument('scopes', nargs='+',
+                   help="Space-separated list of scopes the service principal's role assignment applies to. e.g., "
+                        "subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup, "
+                        "/subscriptions/0b1f6471-1bf0-4dda-aec3-111122223333/resourceGroups/myGroup/providers/Microsoft.Compute/virtualMachines/myVM")
+        c.argument('role', completer=get_role_definition_name_completion_list,
+                   help='Role of the service principal.')
         c.argument('skip_assignment', arg_type=get_three_state_flag(),
                    deprecate_info=c.deprecate(target='--skip-assignment', hide=True), help='No-op.')
         c.argument('show_auth_for_sdk', options_list='--sdk-auth', deprecate_info=c.deprecate(target='--sdk-auth'),
@@ -181,30 +185,41 @@ def load_arguments(self, _):
     with self.argument_context('ad sp owner list') as c:
         c.argument('identifier', options_list=['--id'], help='service principal name, or object id or the service principal')
 
-    for item in ['create-for-rbac', 'credential reset']:
-        with self.argument_context('ad sp {}'.format(item)) as c:
-            c.argument('cert', arg_group='Credential', validator=validate_cert)
-            c.argument('years', type=int, default=None, arg_group='Credential')
+    for item in ['ad app credential reset', 'ad sp credential reset', 'ad sp create-for-rbac']:
+        with self.argument_context(item) as c:
+            # general credential arguments
+            c.argument('years', type=int, default=None, arg_group='Credential',
+                       help='Number of years for which the credentials will be valid. Default: 1 year')
+            c.argument('append', action='store_true', arg_group='Credential',
+                       help='Append the new credential instead of overwriting.')
             c.argument('end_date', default=None, arg_group='Credential',
-                       help="Finer grain of expiry time if '--years' is insufficient, e.g. '2020-12-31T11:59:59+00:00' or '2299-12-31'")
-            c.argument('create_cert', action='store_true', arg_group='Credential')
-            c.argument('keyvault', arg_group='Credential')
-            c.argument('append', action='store_true', help='Append the new credential instead of overwriting.')
+                       help="Finer grain of expiry time if '--years' is insufficient, e.g. '2020-12-31T11:59:59+00:00' "
+                            "or '2299-12-31'")
 
-    with self.argument_context('ad sp credential reset') as c:
-        c.argument('name', name_arg_type)
-        c.argument('display_name', help="Friendly name for the password.", arg_group='Credential')
-        c.argument('password', options_list=['--password', '-p'], arg_group='Credential',
-                   help="If missing, CLI will generate a strong password")
+            # keyCredential arguments
+            c.argument('cert', arg_group='keyCredential', validator=validate_cert,
+                       help='Certificate to use for credentials. When used with `--keyvault,`, indicates the name of the '
+                            'cert to use or create. Otherwise, supply a PEM or DER formatted public certificate string. '
+                            'Use `@{path}` to load from a file. Do not include private key info.')
+            c.argument('create_cert', arg_group='keyCredential', action='store_true',
+                       help='Create a self-signed certificate to use for the credential. Only the current OS user has '
+                            'read/write permission to this certificate. Use with `--keyvault` to create the certificate in '
+                            'Key Vault. Otherwise, a certificate will be created locally.')
+            c.argument('keyvault', arg_group='keyCredential',
+                       help='Name or ID of a KeyVault to use for creating or retrieving certificates.')
 
-    with self.argument_context('ad app credential reset') as c:
-        c.argument('cert', arg_group='Credential', validator=validate_cert, help='Certificate to use for credentials')
-        c.argument('years', type=int, default=None, arg_group='Credential', help='Number of years for which the credentials will be valid')
-        c.argument('append', action='store_true', help='Append the new credential instead of overwriting.')
-        c.argument('display_name', help="Friendly name for the password or key.")
+    # --display-name in `ad sp create-for-rbac` is for the sp, not credential, so we only apply it to `credential reset`
+    # commands.
+    for item in ['ad app credential reset', 'ad sp credential reset']:
+        with self.argument_context(item) as c:
+            c.argument('display_name', arg_group='Credential',
+                       help="Friendly name for the credential.")
 
-        c.argument('create_cert', action='store_true', arg_group='keyCredentials', help='Create a self-signed certificate to use for the credential')
-        c.argument('keyvault', arg_group='keyCredentials', help='Name or ID of a KeyVault to use for creating or retrieving certificates.')
+    for item in ['ad app credential list', 'ad app credential delete',
+                 'ad sp credential list', 'ad sp credential delete']:
+        with self.argument_context(item) as c:
+            c.argument('key_id', help='credential key id')
+            c.argument('cert', action='store_true', help='Operate on certificate credentials')
 
     with self.argument_context('ad app federated-credential') as c:
         c.argument('app_identifier', options_list=['--id'],
@@ -214,11 +229,6 @@ def load_arguments(self, _):
         c.argument('parameters', type=validate_file_or_dict,
                    help='Parameters for creating federated identity credential. ' + JSON_PROPERTY_HELP)
 
-    for item in ['ad sp credential delete', 'ad sp credential list', 'ad app credential delete', 'ad app credential list']:
-        with self.argument_context(item) as c:
-            c.argument('key_id', help='credential key id')
-            c.argument('cert', action='store_true', help='a certificate based credential')
-
     with self.argument_context('ad') as c:
         c.argument('display_name', help='object\'s display name or its prefix')
         c.argument('identifier_uri', help='graph application identifier, must be in uri format')
