@@ -272,6 +272,14 @@ examples:
     text: az servicebus namespace network-rule list --resource-group myresourcegroup --namespace-name mynamespace
 """
 
+helps['servicebus namespace network-rule update'] = """
+type: command
+short-summary: Update network rule properties of the given Namespace.
+examples:
+  - name: Update network rule properties of the given Namespace, can be used to update public network access, trusted service and default action.
+    text: az servicebus namespace network-rule update --resource-group myresourcegroup --namespace-name mynamespace --public-network-access Enabled
+"""
+
 helps['servicebus namespace network-rule remove'] = """
 type: command
 short-summary: Remove network rule for a namespace
