@@ -44,7 +44,7 @@ examples:
           --storage-account testadlsgen2 --file-system testfilesystem \\
           --sql-admin-login-user cliuser1 --sql-admin-login-password Password123! --location "East US" \\
           --repository-type AzureDevOpsGit --account-name testuser --project-name testprj \\
-          --repository-name testrepo --collaboration-branch main
+          --repository-name testrepo --collaboration-branch main --last-commit-id 000000
 """
 
 helps['synapse workspace list'] = """
@@ -504,7 +504,7 @@ examples:
   - name: Set a SQL pool's transparent data encryption configuration. (autogenerated)
     text: |-
         az synapse sql pool tde set --name sqlpool --workspace-name testsynapseworkspace --resource-group rg \\
-        --status Enabled --transparent-data-encryption-name tdename
+        --status Enabled --transparent-data-encryption-name current
 """
 
 helps['synapse sql pool tde show'] = """
@@ -514,7 +514,7 @@ examples:
   - name: Get a SQL pool's transparent data encryption configuration. (autogenerated)
     text: |-
         az synapse sql pool tde show --name sqlpool --workspace-name testsynapseworkspace --resource-group rg \\
-        --transparent-data-encryption-name tdename
+        --transparent-data-encryption-name current
 """
 
 helps['synapse sql pool threat-policy'] = """
@@ -1927,6 +1927,7 @@ examples:
         az synapse managed-private-endpoints create --workspace-name testsynapseworkspace \\
           --pe-name testendpointname \\
           --file @path/test.json
+        test.json {"privateLinkResourceId": "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test/providers/Microsoft.Storage/storageAccounts/test", "groupId": "blob"}
 """
 
 helps['synapse managed-private-endpoints list'] = """
@@ -2273,6 +2274,41 @@ examples:
           --file 'path/test.sql'
 """
 
+helps['synapse ad-only-auth'] = """
+type: group
+short-summary: Manage Azure Active Directly only Authentication settings for this Synapse workspace.
+"""
+
+helps['synapse ad-only-auth get'] = """
+type: command
+short-summary: Get a specific Azure Active Directly only Authentication property.
+examples:
+  - name: Get a specific Azure Active Directly only Authentication property.
+    text: |-
+        az synapse ad-only-auth get --workspace-name testsynapseworkspace \\
+          -g testrg
+"""
+
+helps['synapse ad-only-auth enable'] = """
+type: command
+short-summary: Enable Azure Active Directly only Authentication for this Synapse workspace.
+examples:
+  - name: Enable Azure Active Directly only Authentication for this Synapse workspace.
+    text: |-
+        az synapse ad-only-auth enable --workspace-name testsynapseworkspace \\
+          -g testresourcegroup
+"""
+
+helps['synapse ad-only-auth disable'] = """
+type: command
+short-summary: Disable Azure Active Directly only Authentication for this Synapse workspace.
+examples:
+  - name: Disable Azure Active Directly only Authentication for this Synapse workspace.
+    text: |-
+        az synapse ad-only-auth disable --workspace-name testsynapseworkspace \\
+          -g testresourcegroup
+"""
+
 helps['synapse link-connection'] = """
 type: group
 short-summary: Manage Synapse's link connection.
