@@ -42,3 +42,6 @@ def load_arguments(self, _):
     with self.argument_context('demo style') as c:
         c.argument('theme', arg_type=get_enum_type(Theme),
                    help='The theme to format styled text. If unspecified, the default theme is used.')
+
+    with self.argument_context('demo secret-store save') as c:
+        c.positional('key_value', nargs='+', help="Space-separated data: <key>=<value> [<key>=<value> ...]")
