@@ -17,3 +17,7 @@ def load_command_table(self, _):
 
     with self.command_group('demo', deprecate_info=g.deprecate(hide=True)) as g:
         g.custom_command('style', 'demo_style')
+
+    with self.command_group('demo secret-store') as g:
+        g.custom_command('save', 'secret_store_save')
+        g.custom_command('load', 'secret_store_load')
