@@ -17,7 +17,7 @@ except ImportError:
     logger.warn("Wheel is not available, disabling bdist_wheel hook")
     cmdclass = {}
 
-VERSION = "2.39.0"
+VERSION = "2.40.0"
 # If we have source, validate that our version numbers match
 # This should prevent uploading releases with mismatched versions.
 try:
@@ -76,9 +76,9 @@ DEPENDENCIES = [
     'azure-mgmt-compute~=27.1.0',
     'azure-mgmt-consumption~=2.0',
     'azure-mgmt-containerinstance~=9.1.0',
-    'azure-mgmt-containerregistry==8.2.0',
+    'azure-mgmt-containerregistry==10.0.0',
     'azure-mgmt-containerservice~=20.2.0',
-    'azure-mgmt-cosmosdb==7.0.0b6',
+    'azure-mgmt-cosmosdb==7.0.0',
     'azure-mgmt-databoxedge~=1.0.0',
     'azure-mgmt-datalake-analytics~=0.2.1',
     'azure-mgmt-datalake-store~=0.5.0',
@@ -94,7 +94,7 @@ DEPENDENCIES = [
     'azure-mgmt-iotcentral~=10.0.0b1',
     'azure-mgmt-iothub==2.2.0',
     'azure-mgmt-iothubprovisioningservices==1.1.0',
-    'azure-mgmt-keyvault==9.3.0',
+    'azure-mgmt-keyvault==10.1.0',
     'azure-mgmt-kusto~=0.3.0',
     'azure-mgmt-loganalytics==13.0.0b4',
     'azure-mgmt-managedservices~=1.0',
@@ -102,15 +102,15 @@ DEPENDENCIES = [
     'azure-mgmt-maps~=2.0.0',
     'azure-mgmt-marketplaceordering==1.1.0',
     'azure-mgmt-media~=9.0',
-    'azure-mgmt-monitor~=3.0.0',
-    'azure-mgmt-msi~=6.0.1',
-    'azure-mgmt-netapp~=8.0.0',
-    'azure-mgmt-network~=20.0.0',
+    'azure-mgmt-monitor~=4.0.1',
+    'azure-mgmt-msi~=6.1.0',
+    'azure-mgmt-netapp~=8.1.0',
+    'azure-mgmt-network~=21.0.1',
     'azure-mgmt-policyinsights~=1.1.0b2',
     'azure-mgmt-privatedns~=1.0.0',
-    'azure-mgmt-rdbms~=10.2.0b1',
+    'azure-mgmt-rdbms~=10.2.0b3',
     'azure-mgmt-recoveryservicesbackup~=5.0.0',
-    'azure-mgmt-recoveryservices~=2.0.0',
+    'azure-mgmt-recoveryservices~=2.1.0',
     'azure-mgmt-redhatopenshift==1.1.0',
     'azure-mgmt-redis~=13.1.0',
     'azure-mgmt-relay~=0.1.0',
@@ -118,18 +118,18 @@ DEPENDENCIES = [
     'azure-mgmt-resource==21.1.0b1',
     'azure-mgmt-search~=8.0',
     'azure-mgmt-security==2.0.0b1',
-    'azure-mgmt-servicebus~=7.1.0',
+    'azure-mgmt-servicebus~=8.1.0',
     'azure-mgmt-servicefabricmanagedclusters~=1.0.0',
     'azure-mgmt-servicelinker==1.0.0',
     'azure-mgmt-servicefabric~=1.0.0',
-    'azure-mgmt-signalr==1.0.0b2',
+    'azure-mgmt-signalr==1.1.0',
     'azure-mgmt-sqlvirtualmachine==1.0.0b3',
     'azure-mgmt-sql==4.0.0b2',
-    'azure-mgmt-storage~=20.0.0',
+    'azure-mgmt-storage~=20.1.0',
     'azure-mgmt-synapse==2.1.0b2',
     'azure-mgmt-trafficmanager~=1.0.0',
     'azure-mgmt-web==7.0.0',
-    'azure-multiapi-storage~=0.9.0',
+    'azure-multiapi-storage~=0.10.0',
     'azure-storage-common~=1.4',
     'azure-synapse-accesscontrol~=0.5.0',
     'azure-synapse-artifacts~=0.13.0',
@@ -172,6 +172,7 @@ setup(
         'az',
         'az.completion.sh',
         'az.bat',
+        'az.ps1'
     ],
     packages=find_packages(exclude=["*.tests", "*.tests.*", "tests.*", "tests", "azure", "azure.cli"]),
     install_requires=DEPENDENCIES,
